# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables

class AccountPasswordPolicy(pulumi.CustomResource):
    allow_users_to_change_password: pulumi.Output[bool]
    """
    Whether to allow users to change their own password
    """
    expire_passwords: pulumi.Output[bool]
    """
    Indicates whether passwords in the account expire.
    Returns `true` if `max_password_age` contains a value greater than `0`.
    Returns `false` if it is `0` or _not present_.
    """
    hard_expiry: pulumi.Output[bool]
    """
    Whether users are prevented from setting a new password after their password has expired
    (i.e. require administrator reset)
    """
    max_password_age: pulumi.Output[float]
    """
    The number of days that an user password is valid.
    """
    minimum_password_length: pulumi.Output[float]
    """
    Minimum length to require for user passwords.
    """
    password_reuse_prevention: pulumi.Output[float]
    """
    The number of previous passwords that users are prevented from reusing.
    """
    require_lowercase_characters: pulumi.Output[bool]
    """
    Whether to require lowercase characters for user passwords.
    """
    require_numbers: pulumi.Output[bool]
    """
    Whether to require numbers for user passwords.
    """
    require_symbols: pulumi.Output[bool]
    """
    Whether to require symbols for user passwords.
    """
    require_uppercase_characters: pulumi.Output[bool]
    """
    Whether to require uppercase characters for user passwords.
    """
    def __init__(__self__, resource_name, opts=None, allow_users_to_change_password=None, hard_expiry=None, max_password_age=None, minimum_password_length=None, password_reuse_prevention=None, require_lowercase_characters=None, require_numbers=None, require_symbols=None, require_uppercase_characters=None, __props__=None, __name__=None, __opts__=None):
        """
        > **Note:** There is only a single policy allowed per AWS account. An existing policy will be lost when using this resource as an effect of this limitation.

        Manages Password Policy for the AWS Account.
        See more about [Account Password Policy](http://docs.aws.amazon.com/IAM/latest/UserGuide/id_credentials_passwords_account-policy.html)
        in the official AWS docs.

        ## Example Usage



        ```python
        import pulumi
        import pulumi_aws as aws

        strict = aws.iam.AccountPasswordPolicy("strict",
            allow_users_to_change_password=True,
            minimum_password_length=8,
            require_lowercase_characters=True,
            require_numbers=True,
            require_symbols=True,
            require_uppercase_characters=True)
        ```


        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[bool] allow_users_to_change_password: Whether to allow users to change their own password
        :param pulumi.Input[bool] hard_expiry: Whether users are prevented from setting a new password after their password has expired
               (i.e. require administrator reset)
        :param pulumi.Input[float] max_password_age: The number of days that an user password is valid.
        :param pulumi.Input[float] minimum_password_length: Minimum length to require for user passwords.
        :param pulumi.Input[float] password_reuse_prevention: The number of previous passwords that users are prevented from reusing.
        :param pulumi.Input[bool] require_lowercase_characters: Whether to require lowercase characters for user passwords.
        :param pulumi.Input[bool] require_numbers: Whether to require numbers for user passwords.
        :param pulumi.Input[bool] require_symbols: Whether to require symbols for user passwords.
        :param pulumi.Input[bool] require_uppercase_characters: Whether to require uppercase characters for user passwords.
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            __props__['allow_users_to_change_password'] = allow_users_to_change_password
            __props__['hard_expiry'] = hard_expiry
            __props__['max_password_age'] = max_password_age
            __props__['minimum_password_length'] = minimum_password_length
            __props__['password_reuse_prevention'] = password_reuse_prevention
            __props__['require_lowercase_characters'] = require_lowercase_characters
            __props__['require_numbers'] = require_numbers
            __props__['require_symbols'] = require_symbols
            __props__['require_uppercase_characters'] = require_uppercase_characters
            __props__['expire_passwords'] = None
        super(AccountPasswordPolicy, __self__).__init__(
            'aws:iam/accountPasswordPolicy:AccountPasswordPolicy',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, allow_users_to_change_password=None, expire_passwords=None, hard_expiry=None, max_password_age=None, minimum_password_length=None, password_reuse_prevention=None, require_lowercase_characters=None, require_numbers=None, require_symbols=None, require_uppercase_characters=None):
        """
        Get an existing AccountPasswordPolicy resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[bool] allow_users_to_change_password: Whether to allow users to change their own password
        :param pulumi.Input[bool] expire_passwords: Indicates whether passwords in the account expire.
               Returns `true` if `max_password_age` contains a value greater than `0`.
               Returns `false` if it is `0` or _not present_.
        :param pulumi.Input[bool] hard_expiry: Whether users are prevented from setting a new password after their password has expired
               (i.e. require administrator reset)
        :param pulumi.Input[float] max_password_age: The number of days that an user password is valid.
        :param pulumi.Input[float] minimum_password_length: Minimum length to require for user passwords.
        :param pulumi.Input[float] password_reuse_prevention: The number of previous passwords that users are prevented from reusing.
        :param pulumi.Input[bool] require_lowercase_characters: Whether to require lowercase characters for user passwords.
        :param pulumi.Input[bool] require_numbers: Whether to require numbers for user passwords.
        :param pulumi.Input[bool] require_symbols: Whether to require symbols for user passwords.
        :param pulumi.Input[bool] require_uppercase_characters: Whether to require uppercase characters for user passwords.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()

        __props__["allow_users_to_change_password"] = allow_users_to_change_password
        __props__["expire_passwords"] = expire_passwords
        __props__["hard_expiry"] = hard_expiry
        __props__["max_password_age"] = max_password_age
        __props__["minimum_password_length"] = minimum_password_length
        __props__["password_reuse_prevention"] = password_reuse_prevention
        __props__["require_lowercase_characters"] = require_lowercase_characters
        __props__["require_numbers"] = require_numbers
        __props__["require_symbols"] = require_symbols
        __props__["require_uppercase_characters"] = require_uppercase_characters
        return AccountPasswordPolicy(resource_name, opts=opts, __props__=__props__)
    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables

class Topic(pulumi.CustomResource):
    application_failure_feedback_role_arn: pulumi.Output[str]
    """
    IAM role for failure feedback
    """
    application_success_feedback_role_arn: pulumi.Output[str]
    """
    The IAM role permitted to receive success feedback for this topic
    """
    application_success_feedback_sample_rate: pulumi.Output[float]
    """
    Percentage of success to sample
    """
    arn: pulumi.Output[str]
    """
    The ARN of the SNS topic, as a more obvious property (clone of id)
    """
    delivery_policy: pulumi.Output[str]
    """
    The SNS delivery policy. More on [AWS documentation](https://docs.aws.amazon.com/sns/latest/dg/DeliveryPolicies.html)
    """
    display_name: pulumi.Output[str]
    """
    The display name for the SNS topic
    """
    http_failure_feedback_role_arn: pulumi.Output[str]
    """
    IAM role for failure feedback
    """
    http_success_feedback_role_arn: pulumi.Output[str]
    """
    The IAM role permitted to receive success feedback for this topic
    """
    http_success_feedback_sample_rate: pulumi.Output[float]
    """
    Percentage of success to sample
    """
    kms_master_key_id: pulumi.Output[str]
    """
    The ID of an AWS-managed customer master key (CMK) for Amazon SNS or a custom CMK. For more information, see [Key Terms](https://docs.aws.amazon.com/sns/latest/dg/sns-server-side-encryption.html#sse-key-terms)
    """
    lambda_failure_feedback_role_arn: pulumi.Output[str]
    """
    IAM role for failure feedback
    """
    lambda_success_feedback_role_arn: pulumi.Output[str]
    """
    The IAM role permitted to receive success feedback for this topic
    """
    lambda_success_feedback_sample_rate: pulumi.Output[float]
    """
    Percentage of success to sample
    """
    name: pulumi.Output[str]
    """
    The friendly name for the SNS topic. By default generated by this provider.
    """
    name_prefix: pulumi.Output[str]
    """
    The friendly name for the SNS topic. Conflicts with `name`.
    """
    policy: pulumi.Output[str]
    """
    The fully-formed AWS policy as JSON.
    """
    sqs_failure_feedback_role_arn: pulumi.Output[str]
    """
    IAM role for failure feedback
    """
    sqs_success_feedback_role_arn: pulumi.Output[str]
    """
    The IAM role permitted to receive success feedback for this topic
    """
    sqs_success_feedback_sample_rate: pulumi.Output[float]
    """
    Percentage of success to sample
    """
    tags: pulumi.Output[dict]
    """
    Key-value map of resource tags
    """
    def __init__(__self__, resource_name, opts=None, application_failure_feedback_role_arn=None, application_success_feedback_role_arn=None, application_success_feedback_sample_rate=None, delivery_policy=None, display_name=None, http_failure_feedback_role_arn=None, http_success_feedback_role_arn=None, http_success_feedback_sample_rate=None, kms_master_key_id=None, lambda_failure_feedback_role_arn=None, lambda_success_feedback_role_arn=None, lambda_success_feedback_sample_rate=None, name=None, name_prefix=None, policy=None, sqs_failure_feedback_role_arn=None, sqs_success_feedback_role_arn=None, sqs_success_feedback_sample_rate=None, tags=None, __props__=None, __name__=None, __opts__=None):
        """
        Provides an SNS topic resource

        ## Example Usage



        ```python
        import pulumi
        import pulumi_aws as aws

        user_updates = aws.sns.Topic("userUpdates")
        ```

        ## Example with Delivery Policy

        ```python
        import pulumi
        import pulumi_aws as aws

        user_updates = aws.sns.Topic("userUpdates", delivery_policy=\"\"\"{
          "http": {
            "defaultHealthyRetryPolicy": {
              "minDelayTarget": 20,
              "maxDelayTarget": 20,
              "numRetries": 3,
              "numMaxDelayRetries": 0,
              "numNoDelayRetries": 0,
              "numMinDelayRetries": 0,
              "backoffFunction": "linear"
            },
            "disableSubscriptionOverrides": false,
            "defaultThrottlePolicy": {
              "maxReceivesPerSecond": 1
            }
          }
        }

        \"\"\")
        ```

        ## Example with Server-side encryption (SSE)

        ```python
        import pulumi
        import pulumi_aws as aws

        user_updates = aws.sns.Topic("userUpdates", kms_master_key_id="alias/aws/sns")
        ```

        ## Message Delivery Status Arguments

        The `<endpoint>_success_feedback_role_arn` and `<endpoint>_failure_feedback_role_arn` arguments are used to give Amazon SNS write access to use CloudWatch Logs on your behalf. The `<endpoint>_success_feedback_sample_rate` argument is for specifying the sample rate percentage (0-100) of successfully delivered messages. After you configure the  `<endpoint>_failure_feedback_role_arn` argument, then all failed message deliveries generate CloudWatch Logs.

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] application_failure_feedback_role_arn: IAM role for failure feedback
        :param pulumi.Input[str] application_success_feedback_role_arn: The IAM role permitted to receive success feedback for this topic
        :param pulumi.Input[float] application_success_feedback_sample_rate: Percentage of success to sample
        :param pulumi.Input[str] delivery_policy: The SNS delivery policy. More on [AWS documentation](https://docs.aws.amazon.com/sns/latest/dg/DeliveryPolicies.html)
        :param pulumi.Input[str] display_name: The display name for the SNS topic
        :param pulumi.Input[str] http_failure_feedback_role_arn: IAM role for failure feedback
        :param pulumi.Input[str] http_success_feedback_role_arn: The IAM role permitted to receive success feedback for this topic
        :param pulumi.Input[float] http_success_feedback_sample_rate: Percentage of success to sample
        :param pulumi.Input[str] kms_master_key_id: The ID of an AWS-managed customer master key (CMK) for Amazon SNS or a custom CMK. For more information, see [Key Terms](https://docs.aws.amazon.com/sns/latest/dg/sns-server-side-encryption.html#sse-key-terms)
        :param pulumi.Input[str] lambda_failure_feedback_role_arn: IAM role for failure feedback
        :param pulumi.Input[str] lambda_success_feedback_role_arn: The IAM role permitted to receive success feedback for this topic
        :param pulumi.Input[float] lambda_success_feedback_sample_rate: Percentage of success to sample
        :param pulumi.Input[str] name: The friendly name for the SNS topic. By default generated by this provider.
        :param pulumi.Input[str] name_prefix: The friendly name for the SNS topic. Conflicts with `name`.
        :param pulumi.Input[str] policy: The fully-formed AWS policy as JSON.
        :param pulumi.Input[str] sqs_failure_feedback_role_arn: IAM role for failure feedback
        :param pulumi.Input[str] sqs_success_feedback_role_arn: The IAM role permitted to receive success feedback for this topic
        :param pulumi.Input[float] sqs_success_feedback_sample_rate: Percentage of success to sample
        :param pulumi.Input[dict] tags: Key-value map of resource tags
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            __props__['application_failure_feedback_role_arn'] = application_failure_feedback_role_arn
            __props__['application_success_feedback_role_arn'] = application_success_feedback_role_arn
            __props__['application_success_feedback_sample_rate'] = application_success_feedback_sample_rate
            __props__['delivery_policy'] = delivery_policy
            __props__['display_name'] = display_name
            __props__['http_failure_feedback_role_arn'] = http_failure_feedback_role_arn
            __props__['http_success_feedback_role_arn'] = http_success_feedback_role_arn
            __props__['http_success_feedback_sample_rate'] = http_success_feedback_sample_rate
            __props__['kms_master_key_id'] = kms_master_key_id
            __props__['lambda_failure_feedback_role_arn'] = lambda_failure_feedback_role_arn
            __props__['lambda_success_feedback_role_arn'] = lambda_success_feedback_role_arn
            __props__['lambda_success_feedback_sample_rate'] = lambda_success_feedback_sample_rate
            __props__['name'] = name
            __props__['name_prefix'] = name_prefix
            __props__['policy'] = policy
            __props__['sqs_failure_feedback_role_arn'] = sqs_failure_feedback_role_arn
            __props__['sqs_success_feedback_role_arn'] = sqs_success_feedback_role_arn
            __props__['sqs_success_feedback_sample_rate'] = sqs_success_feedback_sample_rate
            __props__['tags'] = tags
            __props__['arn'] = None
        super(Topic, __self__).__init__(
            'aws:sns/topic:Topic',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, application_failure_feedback_role_arn=None, application_success_feedback_role_arn=None, application_success_feedback_sample_rate=None, arn=None, delivery_policy=None, display_name=None, http_failure_feedback_role_arn=None, http_success_feedback_role_arn=None, http_success_feedback_sample_rate=None, kms_master_key_id=None, lambda_failure_feedback_role_arn=None, lambda_success_feedback_role_arn=None, lambda_success_feedback_sample_rate=None, name=None, name_prefix=None, policy=None, sqs_failure_feedback_role_arn=None, sqs_success_feedback_role_arn=None, sqs_success_feedback_sample_rate=None, tags=None):
        """
        Get an existing Topic resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] application_failure_feedback_role_arn: IAM role for failure feedback
        :param pulumi.Input[str] application_success_feedback_role_arn: The IAM role permitted to receive success feedback for this topic
        :param pulumi.Input[float] application_success_feedback_sample_rate: Percentage of success to sample
        :param pulumi.Input[str] arn: The ARN of the SNS topic, as a more obvious property (clone of id)
        :param pulumi.Input[str] delivery_policy: The SNS delivery policy. More on [AWS documentation](https://docs.aws.amazon.com/sns/latest/dg/DeliveryPolicies.html)
        :param pulumi.Input[str] display_name: The display name for the SNS topic
        :param pulumi.Input[str] http_failure_feedback_role_arn: IAM role for failure feedback
        :param pulumi.Input[str] http_success_feedback_role_arn: The IAM role permitted to receive success feedback for this topic
        :param pulumi.Input[float] http_success_feedback_sample_rate: Percentage of success to sample
        :param pulumi.Input[str] kms_master_key_id: The ID of an AWS-managed customer master key (CMK) for Amazon SNS or a custom CMK. For more information, see [Key Terms](https://docs.aws.amazon.com/sns/latest/dg/sns-server-side-encryption.html#sse-key-terms)
        :param pulumi.Input[str] lambda_failure_feedback_role_arn: IAM role for failure feedback
        :param pulumi.Input[str] lambda_success_feedback_role_arn: The IAM role permitted to receive success feedback for this topic
        :param pulumi.Input[float] lambda_success_feedback_sample_rate: Percentage of success to sample
        :param pulumi.Input[str] name: The friendly name for the SNS topic. By default generated by this provider.
        :param pulumi.Input[str] name_prefix: The friendly name for the SNS topic. Conflicts with `name`.
        :param pulumi.Input[str] policy: The fully-formed AWS policy as JSON.
        :param pulumi.Input[str] sqs_failure_feedback_role_arn: IAM role for failure feedback
        :param pulumi.Input[str] sqs_success_feedback_role_arn: The IAM role permitted to receive success feedback for this topic
        :param pulumi.Input[float] sqs_success_feedback_sample_rate: Percentage of success to sample
        :param pulumi.Input[dict] tags: Key-value map of resource tags
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()

        __props__["application_failure_feedback_role_arn"] = application_failure_feedback_role_arn
        __props__["application_success_feedback_role_arn"] = application_success_feedback_role_arn
        __props__["application_success_feedback_sample_rate"] = application_success_feedback_sample_rate
        __props__["arn"] = arn
        __props__["delivery_policy"] = delivery_policy
        __props__["display_name"] = display_name
        __props__["http_failure_feedback_role_arn"] = http_failure_feedback_role_arn
        __props__["http_success_feedback_role_arn"] = http_success_feedback_role_arn
        __props__["http_success_feedback_sample_rate"] = http_success_feedback_sample_rate
        __props__["kms_master_key_id"] = kms_master_key_id
        __props__["lambda_failure_feedback_role_arn"] = lambda_failure_feedback_role_arn
        __props__["lambda_success_feedback_role_arn"] = lambda_success_feedback_role_arn
        __props__["lambda_success_feedback_sample_rate"] = lambda_success_feedback_sample_rate
        __props__["name"] = name
        __props__["name_prefix"] = name_prefix
        __props__["policy"] = policy
        __props__["sqs_failure_feedback_role_arn"] = sqs_failure_feedback_role_arn
        __props__["sqs_success_feedback_role_arn"] = sqs_success_feedback_role_arn
        __props__["sqs_success_feedback_sample_rate"] = sqs_success_feedback_sample_rate
        __props__["tags"] = tags
        return Topic(resource_name, opts=opts, __props__=__props__)
    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables

class Trigger(pulumi.CustomResource):
    actions: pulumi.Output[list]
    """
    List of actions initiated by this trigger when it fires. Defined below.

      * `arguments` (`dict`) - Arguments to be passed to the job. You can specify arguments here that your own job-execution script consumes, as well as arguments that AWS Glue itself consumes.
      * `crawlerName` (`str`) - The name of the crawler to be executed. Conflicts with `job_name`.
      * `jobName` (`str`) - The name of a job to be executed. Conflicts with `crawler_name`.
      * `timeout` (`float`) - The job run timeout in minutes. It overrides the timeout value of the job.
    """
    arn: pulumi.Output[str]
    """
    Amazon Resource Name (ARN) of Glue Trigger
    """
    description: pulumi.Output[str]
    """
    A description of the new trigger.
    """
    enabled: pulumi.Output[bool]
    """
    Start the trigger. Defaults to `true`. Not valid to disable for `ON_DEMAND` type.
    """
    name: pulumi.Output[str]
    """
    The name of the trigger.
    """
    predicate: pulumi.Output[dict]
    """
    A predicate to specify when the new trigger should fire. Required when trigger type is `CONDITIONAL`. Defined below.

      * `conditions` (`list`) - A list of the conditions that determine when the trigger will fire. Defined below.
        * `crawlState` (`str`) - The condition crawl state. Currently, the values supported are `RUNNING`, `SUCCEEDED`, `CANCELLED`, and `FAILED`. If this is specified, `crawler_name` must also be specified. Conflicts with `state`.
        * `crawlerName` (`str`) - The name of the crawler to watch. If this is specified, `crawl_state` must also be specified. Conflicts with `job_name`.
        * `jobName` (`str`) - The name of the job to watch. If this is specified, `state` must also be specified. Conflicts with `crawler_name`.
        * `logicalOperator` (`str`) - A logical operator. Defaults to `EQUALS`.
        * `state` (`str`) - The condition job state. Currently, the values supported are `SUCCEEDED`, `STOPPED`, `TIMEOUT` and `FAILED`. If this is specified, `job_name` must also be specified. Conflicts with `crawler_state`.

      * `logical` (`str`) - How to handle multiple conditions. Defaults to `AND`. Valid values are `AND` or `ANY`.
    """
    schedule: pulumi.Output[str]
    """
    A cron expression used to specify the schedule. [Time-Based Schedules for Jobs and Crawlers](https://docs.aws.amazon.com/glue/latest/dg/monitor-data-warehouse-schedule.html)
    """
    tags: pulumi.Output[dict]
    """
    Key-value map of resource tags
    """
    type: pulumi.Output[str]
    """
    The type of trigger. Valid values are `CONDITIONAL`, `ON_DEMAND`, and `SCHEDULED`.
    """
    workflow_name: pulumi.Output[str]
    """
    A workflow to which the trigger should be associated to. Every workflow graph (DAG) needs a starting trigger (`ON_DEMAND` or `SCHEDULED` type) and can contain multiple additional `CONDITIONAL` triggers.
    """
    def __init__(__self__, resource_name, opts=None, actions=None, description=None, enabled=None, name=None, predicate=None, schedule=None, tags=None, type=None, workflow_name=None, __props__=None, __name__=None, __opts__=None):
        """
        Manages a Glue Trigger resource.

        ## Example Usage

        ### Conditional Trigger

        ```python
        import pulumi
        import pulumi_aws as aws

        example = aws.glue.Trigger("example",
            actions=[{
                "jobName": aws_glue_job["example1"]["name"],
            }],
            predicate={
                "conditions": [{
                    "jobName": aws_glue_job["example2"]["name"],
                    "state": "SUCCEEDED",
                }],
            },
            type="CONDITIONAL")
        ```

        ### On-Demand Trigger

        ```python
        import pulumi
        import pulumi_aws as aws

        example = aws.glue.Trigger("example",
            actions=[{
                "jobName": aws_glue_job["example"]["name"],
            }],
            type="ON_DEMAND")
        ```

        ### Scheduled Trigger

        ```python
        import pulumi
        import pulumi_aws as aws

        example = aws.glue.Trigger("example",
            actions=[{
                "jobName": aws_glue_job["example"]["name"],
            }],
            schedule="cron(15 12 * * ? *)",
            type="SCHEDULED")
        ```

        ### Conditional Trigger with Crawler Action

        ```python
        import pulumi
        import pulumi_aws as aws

        example = aws.glue.Trigger("example",
            actions=[{
                "crawlerName": aws_glue_crawler["example1"]["name"],
            }],
            predicate={
                "conditions": [{
                    "jobName": aws_glue_job["example2"]["name"],
                    "state": "SUCCEEDED",
                }],
            },
            type="CONDITIONAL")
        ```

        ### Conditional Trigger with Crawler Condition 

        ```python
        import pulumi
        import pulumi_aws as aws

        example = aws.glue.Trigger("example",
            actions=[{
                "jobName": aws_glue_job["example1"]["name"],
            }],
            predicate={
                "conditions": [{
                    "crawlState": "SUCCEEDED",
                    "crawlerName": aws_glue_crawler["example2"]["name"],
                }],
            },
            type="CONDITIONAL")
        ```


        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[list] actions: List of actions initiated by this trigger when it fires. Defined below.
        :param pulumi.Input[str] description: A description of the new trigger.
        :param pulumi.Input[bool] enabled: Start the trigger. Defaults to `true`. Not valid to disable for `ON_DEMAND` type.
        :param pulumi.Input[str] name: The name of the trigger.
        :param pulumi.Input[dict] predicate: A predicate to specify when the new trigger should fire. Required when trigger type is `CONDITIONAL`. Defined below.
        :param pulumi.Input[str] schedule: A cron expression used to specify the schedule. [Time-Based Schedules for Jobs and Crawlers](https://docs.aws.amazon.com/glue/latest/dg/monitor-data-warehouse-schedule.html)
        :param pulumi.Input[dict] tags: Key-value map of resource tags
        :param pulumi.Input[str] type: The type of trigger. Valid values are `CONDITIONAL`, `ON_DEMAND`, and `SCHEDULED`.
        :param pulumi.Input[str] workflow_name: A workflow to which the trigger should be associated to. Every workflow graph (DAG) needs a starting trigger (`ON_DEMAND` or `SCHEDULED` type) and can contain multiple additional `CONDITIONAL` triggers.

        The **actions** object supports the following:

          * `arguments` (`pulumi.Input[dict]`) - Arguments to be passed to the job. You can specify arguments here that your own job-execution script consumes, as well as arguments that AWS Glue itself consumes.
          * `crawlerName` (`pulumi.Input[str]`) - The name of the crawler to be executed. Conflicts with `job_name`.
          * `jobName` (`pulumi.Input[str]`) - The name of a job to be executed. Conflicts with `crawler_name`.
          * `timeout` (`pulumi.Input[float]`) - The job run timeout in minutes. It overrides the timeout value of the job.

        The **predicate** object supports the following:

          * `conditions` (`pulumi.Input[list]`) - A list of the conditions that determine when the trigger will fire. Defined below.
            * `crawlState` (`pulumi.Input[str]`) - The condition crawl state. Currently, the values supported are `RUNNING`, `SUCCEEDED`, `CANCELLED`, and `FAILED`. If this is specified, `crawler_name` must also be specified. Conflicts with `state`.
            * `crawlerName` (`pulumi.Input[str]`) - The name of the crawler to watch. If this is specified, `crawl_state` must also be specified. Conflicts with `job_name`.
            * `jobName` (`pulumi.Input[str]`) - The name of the job to watch. If this is specified, `state` must also be specified. Conflicts with `crawler_name`.
            * `logicalOperator` (`pulumi.Input[str]`) - A logical operator. Defaults to `EQUALS`.
            * `state` (`pulumi.Input[str]`) - The condition job state. Currently, the values supported are `SUCCEEDED`, `STOPPED`, `TIMEOUT` and `FAILED`. If this is specified, `job_name` must also be specified. Conflicts with `crawler_state`.

          * `logical` (`pulumi.Input[str]`) - How to handle multiple conditions. Defaults to `AND`. Valid values are `AND` or `ANY`.
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            if actions is None:
                raise TypeError("Missing required property 'actions'")
            __props__['actions'] = actions
            __props__['description'] = description
            __props__['enabled'] = enabled
            __props__['name'] = name
            __props__['predicate'] = predicate
            __props__['schedule'] = schedule
            __props__['tags'] = tags
            if type is None:
                raise TypeError("Missing required property 'type'")
            __props__['type'] = type
            __props__['workflow_name'] = workflow_name
            __props__['arn'] = None
        super(Trigger, __self__).__init__(
            'aws:glue/trigger:Trigger',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, actions=None, arn=None, description=None, enabled=None, name=None, predicate=None, schedule=None, tags=None, type=None, workflow_name=None):
        """
        Get an existing Trigger resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[list] actions: List of actions initiated by this trigger when it fires. Defined below.
        :param pulumi.Input[str] arn: Amazon Resource Name (ARN) of Glue Trigger
        :param pulumi.Input[str] description: A description of the new trigger.
        :param pulumi.Input[bool] enabled: Start the trigger. Defaults to `true`. Not valid to disable for `ON_DEMAND` type.
        :param pulumi.Input[str] name: The name of the trigger.
        :param pulumi.Input[dict] predicate: A predicate to specify when the new trigger should fire. Required when trigger type is `CONDITIONAL`. Defined below.
        :param pulumi.Input[str] schedule: A cron expression used to specify the schedule. [Time-Based Schedules for Jobs and Crawlers](https://docs.aws.amazon.com/glue/latest/dg/monitor-data-warehouse-schedule.html)
        :param pulumi.Input[dict] tags: Key-value map of resource tags
        :param pulumi.Input[str] type: The type of trigger. Valid values are `CONDITIONAL`, `ON_DEMAND`, and `SCHEDULED`.
        :param pulumi.Input[str] workflow_name: A workflow to which the trigger should be associated to. Every workflow graph (DAG) needs a starting trigger (`ON_DEMAND` or `SCHEDULED` type) and can contain multiple additional `CONDITIONAL` triggers.

        The **actions** object supports the following:

          * `arguments` (`pulumi.Input[dict]`) - Arguments to be passed to the job. You can specify arguments here that your own job-execution script consumes, as well as arguments that AWS Glue itself consumes.
          * `crawlerName` (`pulumi.Input[str]`) - The name of the crawler to be executed. Conflicts with `job_name`.
          * `jobName` (`pulumi.Input[str]`) - The name of a job to be executed. Conflicts with `crawler_name`.
          * `timeout` (`pulumi.Input[float]`) - The job run timeout in minutes. It overrides the timeout value of the job.

        The **predicate** object supports the following:

          * `conditions` (`pulumi.Input[list]`) - A list of the conditions that determine when the trigger will fire. Defined below.
            * `crawlState` (`pulumi.Input[str]`) - The condition crawl state. Currently, the values supported are `RUNNING`, `SUCCEEDED`, `CANCELLED`, and `FAILED`. If this is specified, `crawler_name` must also be specified. Conflicts with `state`.
            * `crawlerName` (`pulumi.Input[str]`) - The name of the crawler to watch. If this is specified, `crawl_state` must also be specified. Conflicts with `job_name`.
            * `jobName` (`pulumi.Input[str]`) - The name of the job to watch. If this is specified, `state` must also be specified. Conflicts with `crawler_name`.
            * `logicalOperator` (`pulumi.Input[str]`) - A logical operator. Defaults to `EQUALS`.
            * `state` (`pulumi.Input[str]`) - The condition job state. Currently, the values supported are `SUCCEEDED`, `STOPPED`, `TIMEOUT` and `FAILED`. If this is specified, `job_name` must also be specified. Conflicts with `crawler_state`.

          * `logical` (`pulumi.Input[str]`) - How to handle multiple conditions. Defaults to `AND`. Valid values are `AND` or `ANY`.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()

        __props__["actions"] = actions
        __props__["arn"] = arn
        __props__["description"] = description
        __props__["enabled"] = enabled
        __props__["name"] = name
        __props__["predicate"] = predicate
        __props__["schedule"] = schedule
        __props__["tags"] = tags
        __props__["type"] = type
        __props__["workflow_name"] = workflow_name
        return Trigger(resource_name, opts=opts, __props__=__props__)
    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables

class EventSubscription(pulumi.CustomResource):
    arn: pulumi.Output[str]
    customer_aws_id: pulumi.Output[str]
    enabled: pulumi.Output[bool]
    """
    A boolean flag to enable/disable the subscription. Defaults to true.
    """
    event_categories: pulumi.Output[list]
    """
    A list of event categories for a `source_type` that you want to subscribe to. Run `aws neptune describe-event-categories` to find all the event categories.
    """
    name: pulumi.Output[str]
    """
    The name of the Neptune event subscription. By default generated by this provider.
    """
    name_prefix: pulumi.Output[str]
    """
    The name of the Neptune event subscription. Conflicts with `name`.
    """
    sns_topic_arn: pulumi.Output[str]
    """
    The ARN of the SNS topic to send events to.
    """
    source_ids: pulumi.Output[list]
    """
    A list of identifiers of the event sources for which events will be returned. If not specified, then all sources are included in the response. If specified, a `source_type` must also be specified.
    """
    source_type: pulumi.Output[str]
    """
    The type of source that will be generating the events. Valid options are `db-instance`, `db-security-group`, `db-parameter-group`, `db-snapshot`, `db-cluster` or `db-cluster-snapshot`. If not set, all sources will be subscribed to.
    """
    tags: pulumi.Output[dict]
    """
    A map of tags to assign to the resource.
    """
    def __init__(__self__, resource_name, opts=None, enabled=None, event_categories=None, name=None, name_prefix=None, sns_topic_arn=None, source_ids=None, source_type=None, tags=None, __props__=None, __name__=None, __opts__=None):
        """
        ## Example Usage



        ```python
        import pulumi
        import pulumi_aws as aws

        default_cluster = aws.neptune.Cluster("defaultCluster",
            apply_immediately="true",
            backup_retention_period=5,
            cluster_identifier="neptune-cluster-demo",
            engine="neptune",
            iam_database_authentication_enabled="true",
            preferred_backup_window="07:00-09:00",
            skip_final_snapshot=True)
        example = aws.neptune.ClusterInstance("example",
            apply_immediately="true",
            cluster_identifier=default_cluster.id,
            engine="neptune",
            instance_class="db.r4.large")
        default_topic = aws.sns.Topic("defaultTopic")
        default_event_subscription = aws.neptune.EventSubscription("defaultEventSubscription",
            event_categories=[
                "maintenance",
                "availability",
                "creation",
                "backup",
                "restoration",
                "recovery",
                "deletion",
                "failover",
                "failure",
                "notification",
                "configuration change",
                "read replica",
            ],
            sns_topic_arn=default_topic.arn,
            source_ids=[example.id],
            source_type="db-instance",
            tags={
                "env": "test",
            })
        ```

        ## Attributes

        The following additional atttributes are provided:

        * `id` - The name of the Neptune event notification subscription.
        * `arn` - The Amazon Resource Name of the Neptune event notification subscription.
        * `customer_aws_id` - The AWS customer account associated with the Neptune event notification subscription.

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[bool] enabled: A boolean flag to enable/disable the subscription. Defaults to true.
        :param pulumi.Input[list] event_categories: A list of event categories for a `source_type` that you want to subscribe to. Run `aws neptune describe-event-categories` to find all the event categories.
        :param pulumi.Input[str] name: The name of the Neptune event subscription. By default generated by this provider.
        :param pulumi.Input[str] name_prefix: The name of the Neptune event subscription. Conflicts with `name`.
        :param pulumi.Input[str] sns_topic_arn: The ARN of the SNS topic to send events to.
        :param pulumi.Input[list] source_ids: A list of identifiers of the event sources for which events will be returned. If not specified, then all sources are included in the response. If specified, a `source_type` must also be specified.
        :param pulumi.Input[str] source_type: The type of source that will be generating the events. Valid options are `db-instance`, `db-security-group`, `db-parameter-group`, `db-snapshot`, `db-cluster` or `db-cluster-snapshot`. If not set, all sources will be subscribed to.
        :param pulumi.Input[dict] tags: A map of tags to assign to the resource.
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            __props__['enabled'] = enabled
            __props__['event_categories'] = event_categories
            __props__['name'] = name
            __props__['name_prefix'] = name_prefix
            if sns_topic_arn is None:
                raise TypeError("Missing required property 'sns_topic_arn'")
            __props__['sns_topic_arn'] = sns_topic_arn
            __props__['source_ids'] = source_ids
            __props__['source_type'] = source_type
            __props__['tags'] = tags
            __props__['arn'] = None
            __props__['customer_aws_id'] = None
        super(EventSubscription, __self__).__init__(
            'aws:neptune/eventSubscription:EventSubscription',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, arn=None, customer_aws_id=None, enabled=None, event_categories=None, name=None, name_prefix=None, sns_topic_arn=None, source_ids=None, source_type=None, tags=None):
        """
        Get an existing EventSubscription resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[bool] enabled: A boolean flag to enable/disable the subscription. Defaults to true.
        :param pulumi.Input[list] event_categories: A list of event categories for a `source_type` that you want to subscribe to. Run `aws neptune describe-event-categories` to find all the event categories.
        :param pulumi.Input[str] name: The name of the Neptune event subscription. By default generated by this provider.
        :param pulumi.Input[str] name_prefix: The name of the Neptune event subscription. Conflicts with `name`.
        :param pulumi.Input[str] sns_topic_arn: The ARN of the SNS topic to send events to.
        :param pulumi.Input[list] source_ids: A list of identifiers of the event sources for which events will be returned. If not specified, then all sources are included in the response. If specified, a `source_type` must also be specified.
        :param pulumi.Input[str] source_type: The type of source that will be generating the events. Valid options are `db-instance`, `db-security-group`, `db-parameter-group`, `db-snapshot`, `db-cluster` or `db-cluster-snapshot`. If not set, all sources will be subscribed to.
        :param pulumi.Input[dict] tags: A map of tags to assign to the resource.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()

        __props__["arn"] = arn
        __props__["customer_aws_id"] = customer_aws_id
        __props__["enabled"] = enabled
        __props__["event_categories"] = event_categories
        __props__["name"] = name
        __props__["name_prefix"] = name_prefix
        __props__["sns_topic_arn"] = sns_topic_arn
        __props__["source_ids"] = source_ids
        __props__["source_type"] = source_type
        __props__["tags"] = tags
        return EventSubscription(resource_name, opts=opts, __props__=__props__)
    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables

class BgpPeer(pulumi.CustomResource):
    address_family: pulumi.Output[str]
    """
    The address family for the BGP peer. `ipv4 ` or `ipv6`.
    """
    amazon_address: pulumi.Output[str]
    """
    The IPv4 CIDR address to use to send traffic to Amazon.
    Required for IPv4 BGP peers on public virtual interfaces.
    """
    aws_device: pulumi.Output[str]
    """
    The Direct Connect endpoint on which the BGP peer terminates.
    """
    bgp_asn: pulumi.Output[float]
    """
    The autonomous system (AS) number for Border Gateway Protocol (BGP) configuration.
    """
    bgp_auth_key: pulumi.Output[str]
    """
    The authentication key for BGP configuration.
    """
    bgp_peer_id: pulumi.Output[str]
    """
    The ID of the BGP peer.
    """
    bgp_status: pulumi.Output[str]
    """
    The Up/Down state of the BGP peer.
    """
    customer_address: pulumi.Output[str]
    """
    The IPv4 CIDR destination address to which Amazon should send traffic.
    Required for IPv4 BGP peers on public virtual interfaces.
    """
    virtual_interface_id: pulumi.Output[str]
    """
    The ID of the Direct Connect virtual interface on which to create the BGP peer.
    """
    def __init__(__self__, resource_name, opts=None, address_family=None, amazon_address=None, bgp_asn=None, bgp_auth_key=None, customer_address=None, virtual_interface_id=None, __props__=None, __name__=None, __opts__=None):
        """
        Provides a Direct Connect BGP peer resource.

        ## Example Usage



        ```python
        import pulumi
        import pulumi_aws as aws

        peer = aws.directconnect.BgpPeer("peer",
            address_family="ipv6",
            bgp_asn=65351,
            virtual_interface_id=aws_dx_private_virtual_interface["foo"]["id"])
        ```


        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] address_family: The address family for the BGP peer. `ipv4 ` or `ipv6`.
        :param pulumi.Input[str] amazon_address: The IPv4 CIDR address to use to send traffic to Amazon.
               Required for IPv4 BGP peers on public virtual interfaces.
        :param pulumi.Input[float] bgp_asn: The autonomous system (AS) number for Border Gateway Protocol (BGP) configuration.
        :param pulumi.Input[str] bgp_auth_key: The authentication key for BGP configuration.
        :param pulumi.Input[str] customer_address: The IPv4 CIDR destination address to which Amazon should send traffic.
               Required for IPv4 BGP peers on public virtual interfaces.
        :param pulumi.Input[str] virtual_interface_id: The ID of the Direct Connect virtual interface on which to create the BGP peer.
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            if address_family is None:
                raise TypeError("Missing required property 'address_family'")
            __props__['address_family'] = address_family
            __props__['amazon_address'] = amazon_address
            if bgp_asn is None:
                raise TypeError("Missing required property 'bgp_asn'")
            __props__['bgp_asn'] = bgp_asn
            __props__['bgp_auth_key'] = bgp_auth_key
            __props__['customer_address'] = customer_address
            if virtual_interface_id is None:
                raise TypeError("Missing required property 'virtual_interface_id'")
            __props__['virtual_interface_id'] = virtual_interface_id
            __props__['aws_device'] = None
            __props__['bgp_peer_id'] = None
            __props__['bgp_status'] = None
        super(BgpPeer, __self__).__init__(
            'aws:directconnect/bgpPeer:BgpPeer',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, address_family=None, amazon_address=None, aws_device=None, bgp_asn=None, bgp_auth_key=None, bgp_peer_id=None, bgp_status=None, customer_address=None, virtual_interface_id=None):
        """
        Get an existing BgpPeer resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] address_family: The address family for the BGP peer. `ipv4 ` or `ipv6`.
        :param pulumi.Input[str] amazon_address: The IPv4 CIDR address to use to send traffic to Amazon.
               Required for IPv4 BGP peers on public virtual interfaces.
        :param pulumi.Input[str] aws_device: The Direct Connect endpoint on which the BGP peer terminates.
        :param pulumi.Input[float] bgp_asn: The autonomous system (AS) number for Border Gateway Protocol (BGP) configuration.
        :param pulumi.Input[str] bgp_auth_key: The authentication key for BGP configuration.
        :param pulumi.Input[str] bgp_peer_id: The ID of the BGP peer.
        :param pulumi.Input[str] bgp_status: The Up/Down state of the BGP peer.
        :param pulumi.Input[str] customer_address: The IPv4 CIDR destination address to which Amazon should send traffic.
               Required for IPv4 BGP peers on public virtual interfaces.
        :param pulumi.Input[str] virtual_interface_id: The ID of the Direct Connect virtual interface on which to create the BGP peer.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()

        __props__["address_family"] = address_family
        __props__["amazon_address"] = amazon_address
        __props__["aws_device"] = aws_device
        __props__["bgp_asn"] = bgp_asn
        __props__["bgp_auth_key"] = bgp_auth_key
        __props__["bgp_peer_id"] = bgp_peer_id
        __props__["bgp_status"] = bgp_status
        __props__["customer_address"] = customer_address
        __props__["virtual_interface_id"] = virtual_interface_id
        return BgpPeer(resource_name, opts=opts, __props__=__props__)
    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables

class Distribution(pulumi.CustomResource):
    active_trusted_signers: pulumi.Output[dict]
    """
    The key pair IDs that CloudFront is aware of for
    each trusted signer, if the distribution is set up to serve private content
    with signed URLs.
    """
    aliases: pulumi.Output[list]
    """
    Extra CNAMEs (alternate domain names), if any, for
    this distribution.
    """
    arn: pulumi.Output[str]
    """
    The ARN (Amazon Resource Name) for the distribution. For example: arn:aws:cloudfront::123456789012:distribution/EDFDVBD632BHDS5, where 123456789012 is your AWS account ID.
    """
    caller_reference: pulumi.Output[str]
    """
    Internal value used by CloudFront to allow future
    updates to the distribution configuration.
    """
    comment: pulumi.Output[str]
    """
    Any comments you want to include about the
    distribution.
    """
    custom_error_responses: pulumi.Output[list]
    """
    One or more custom error response elements (multiples allowed).

      * `errorCachingMinTtl` (`float`) - The minimum amount of time you want
        HTTP error codes to stay in CloudFront caches before CloudFront queries your
        origin to see whether the object has been updated.
      * `errorCode` (`float`) - The 4xx or 5xx HTTP status code that you want to
        customize.
      * `responseCode` (`float`) - The HTTP status code that you want CloudFront
        to return with the custom error page to the viewer.
      * `responsePagePath` (`str`) - The path of the custom error page (for
        example, `/custom_404.html`).
    """
    default_cache_behavior: pulumi.Output[dict]
    """
    The default cache behavior for this distribution (maximum
    one).

      * `allowedMethods` (`list`) - Controls which HTTP methods CloudFront
        processes and forwards to your Amazon S3 bucket or your custom origin.
      * `cachedMethods` (`list`) - Controls whether CloudFront caches the
        response to requests using the specified HTTP methods.
      * `compress` (`bool`) - Whether you want CloudFront to automatically
        compress content for web requests that include `Accept-Encoding: gzip` in
        the request header (default: `false`).
      * `defaultTtl` (`float`) - The default amount of time (in seconds) that an
        object is in a CloudFront cache before CloudFront forwards another request
        in the absence of an `Cache-Control max-age` or `Expires` header. Defaults to
        1 day.
      * `fieldLevelEncryptionId` (`str`) - Field level encryption configuration ID
      * `forwardedValues` (`dict`) - The forwarded values configuration that specifies how CloudFront
        handles query strings, cookies and headers (maximum one).
        * `cookies` (`dict`) - The forwarded values cookies
          that specifies how CloudFront handles cookies (maximum one).
          * `forward` (`str`) - Specifies whether you want CloudFront to forward
            cookies to the origin that is associated with this cache behavior. You can
            specify `all`, `none` or `whitelist`. If `whitelist`, you must include the
            subsequent `whitelisted_names`
          * `whitelistedNames` (`list`) - If you have specified `whitelist` to
            `forward`, the whitelisted cookies that you want CloudFront to forward to
            your origin.

        * `headers` (`list`) - Specifies the Headers, if any, that you want
          CloudFront to vary upon for this cache behavior. Specify `*` to include all
          headers.
        * `queryString` (`bool`) - Indicates whether you want CloudFront to forward
          query strings to the origin that is associated with this cache behavior.
        * `queryStringCacheKeys` (`list`) - When specified, along with a value of
          `true` for `query_string`, all query strings are forwarded, however only the
          query string keys listed in this argument are cached. When omitted with a
          value of `true` for `query_string`, all query string keys are cached.

      * `lambdaFunctionAssociations` (`list`) - A config block that triggers a lambda function with
        specific actions. Defined below, maximum 4.
        * `eventType` (`str`) - The specific event to trigger this function.
          Valid values: `viewer-request`, `origin-request`, `viewer-response`,
          `origin-response`
        * `includeBody` (`bool`) - When set to true it exposes the request body to the lambda function. Defaults to false. Valid values: `true`, `false`.
        * `lambdaArn` (`str`) - ARN of the Lambda function.

      * `maxTtl` (`float`) - The maximum amount of time (in seconds) that an
        object is in a CloudFront cache before CloudFront forwards another request
        to your origin to determine whether the object has been updated. Only
        effective in the presence of `Cache-Control max-age`, `Cache-Control
        s-maxage`, and `Expires` headers. Defaults to 365 days.
      * `minTtl` (`float`) - The minimum amount of time that you want objects to
        stay in CloudFront caches before CloudFront queries your origin to see
        whether the object has been updated. Defaults to 0 seconds.
      * `smoothStreaming` (`bool`) - Indicates whether you want to distribute
        media files in Microsoft Smooth Streaming format using the origin that is
        associated with this cache behavior.
      * `targetOriginId` (`str`) - The value of ID for the origin that you want
        CloudFront to route requests to when a request matches the path pattern
        either for a cache behavior or for the default cache behavior.
      * `trustedSigners` (`list`) - The AWS accounts, if any, that you want to
        allow to create signed URLs for private content.
      * `viewerProtocolPolicy` (`str`) - Use this element to specify the
        protocol that users can use to access the files in the origin specified by
        TargetOriginId when a request matches the path pattern in PathPattern. One
        of `allow-all`, `https-only`, or `redirect-to-https`.
    """
    default_root_object: pulumi.Output[str]
    """
    The object that you want CloudFront to
    return (for example, index.html) when an end user requests the root URL.
    """
    domain_name: pulumi.Output[str]
    """
    The DNS domain name of either the S3 bucket, or
    web site of your custom origin.
    """
    enabled: pulumi.Output[bool]
    """
    Whether the distribution is enabled to accept end
    user requests for content.
    """
    etag: pulumi.Output[str]
    """
    The current version of the distribution's information. For example:
    `E2QWRUHAPOMQZL`.
    """
    hosted_zone_id: pulumi.Output[str]
    """
    The CloudFront Route 53 zone ID that can be used to
    route an [Alias Resource Record Set](http://docs.aws.amazon.com/Route53/latest/APIReference/CreateAliasRRSAPI.html) to. This attribute is simply an
    alias for the zone ID `Z2FDTNDATAQYW2`.
    """
    http_version: pulumi.Output[str]
    """
    The maximum HTTP version to support on the
    distribution. Allowed values are `http1.1` and `http2`. The default is
    `http2`.
    """
    in_progress_validation_batches: pulumi.Output[float]
    """
    The number of invalidation batches
    currently in progress.
    """
    is_ipv6_enabled: pulumi.Output[bool]
    """
    Whether the IPv6 is enabled for the distribution.
    """
    last_modified_time: pulumi.Output[str]
    """
    The date and time the distribution was last modified.
    """
    logging_config: pulumi.Output[dict]
    """
    The logging
    configuration that controls how logs are written
    to your distribution (maximum one).

      * `bucket` (`str`) - The Amazon S3 bucket to store the access logs in, for
        example, `myawslogbucket.s3.amazonaws.com`.
      * `includeCookies` (`bool`) - Specifies whether you want CloudFront to
        include cookies in access logs (default: `false`).
      * `prefix` (`str`) - An optional string that you want CloudFront to prefix
        to the access log filenames for this distribution, for example, `myprefix/`.
    """
    ordered_cache_behaviors: pulumi.Output[list]
    """
    An ordered list of cache behaviors
    resource for this distribution. List from top to bottom
    in order of precedence. The topmost cache behavior will have precedence 0.

      * `allowedMethods` (`list`) - Controls which HTTP methods CloudFront
        processes and forwards to your Amazon S3 bucket or your custom origin.
      * `cachedMethods` (`list`) - Controls whether CloudFront caches the
        response to requests using the specified HTTP methods.
      * `compress` (`bool`) - Whether you want CloudFront to automatically
        compress content for web requests that include `Accept-Encoding: gzip` in
        the request header (default: `false`).
      * `defaultTtl` (`float`) - The default amount of time (in seconds) that an
        object is in a CloudFront cache before CloudFront forwards another request
        in the absence of an `Cache-Control max-age` or `Expires` header. Defaults to
        1 day.
      * `fieldLevelEncryptionId` (`str`) - Field level encryption configuration ID
      * `forwardedValues` (`dict`) - The forwarded values configuration that specifies how CloudFront
        handles query strings, cookies and headers (maximum one).
        * `cookies` (`dict`) - The forwarded values cookies
          that specifies how CloudFront handles cookies (maximum one).
          * `forward` (`str`) - Specifies whether you want CloudFront to forward
            cookies to the origin that is associated with this cache behavior. You can
            specify `all`, `none` or `whitelist`. If `whitelist`, you must include the
            subsequent `whitelisted_names`
          * `whitelistedNames` (`list`) - If you have specified `whitelist` to
            `forward`, the whitelisted cookies that you want CloudFront to forward to
            your origin.

        * `headers` (`list`) - Specifies the Headers, if any, that you want
          CloudFront to vary upon for this cache behavior. Specify `*` to include all
          headers.
        * `queryString` (`bool`) - Indicates whether you want CloudFront to forward
          query strings to the origin that is associated with this cache behavior.
        * `queryStringCacheKeys` (`list`) - When specified, along with a value of
          `true` for `query_string`, all query strings are forwarded, however only the
          query string keys listed in this argument are cached. When omitted with a
          value of `true` for `query_string`, all query string keys are cached.

      * `lambdaFunctionAssociations` (`list`) - A config block that triggers a lambda function with
        specific actions. Defined below, maximum 4.
        * `eventType` (`str`) - The specific event to trigger this function.
          Valid values: `viewer-request`, `origin-request`, `viewer-response`,
          `origin-response`
        * `includeBody` (`bool`) - When set to true it exposes the request body to the lambda function. Defaults to false. Valid values: `true`, `false`.
        * `lambdaArn` (`str`) - ARN of the Lambda function.

      * `maxTtl` (`float`) - The maximum amount of time (in seconds) that an
        object is in a CloudFront cache before CloudFront forwards another request
        to your origin to determine whether the object has been updated. Only
        effective in the presence of `Cache-Control max-age`, `Cache-Control
        s-maxage`, and `Expires` headers. Defaults to 365 days.
      * `minTtl` (`float`) - The minimum amount of time that you want objects to
        stay in CloudFront caches before CloudFront queries your origin to see
        whether the object has been updated. Defaults to 0 seconds.
      * `pathPattern` (`str`) - The pattern (for example, `images/*.jpg)` that
        specifies which requests you want this cache behavior to apply to.
      * `smoothStreaming` (`bool`) - Indicates whether you want to distribute
        media files in Microsoft Smooth Streaming format using the origin that is
        associated with this cache behavior.
      * `targetOriginId` (`str`) - The value of ID for the origin that you want
        CloudFront to route requests to when a request matches the path pattern
        either for a cache behavior or for the default cache behavior.
      * `trustedSigners` (`list`) - The AWS accounts, if any, that you want to
        allow to create signed URLs for private content.
      * `viewerProtocolPolicy` (`str`) - Use this element to specify the
        protocol that users can use to access the files in the origin specified by
        TargetOriginId when a request matches the path pattern in PathPattern. One
        of `allow-all`, `https-only`, or `redirect-to-https`.
    """
    origin_groups: pulumi.Output[list]
    """
    One or more origin_group for this
    distribution (multiples allowed).

      * `failoverCriteria` (`dict`) - The failover criteria for when to failover to the secondary origin
        * `statusCodes` (`list`) - A list of HTTP status codes for the origin group

      * `members` (`list`) - Ordered member configuration blocks assigned to the origin group, where the first member is the primary origin. You must specify two members.
        * `originId` (`str`) - The unique identifier of the member origin

      * `originId` (`str`) - The unique identifier of the member origin
    """
    origins: pulumi.Output[list]
    """
    One or more origins for this
    distribution (multiples allowed).

      * `customHeaders` (`list`) - One or more sub-resources with `name` and
        `value` parameters that specify header data that will be sent to the origin
        (multiples allowed).
        * `name` (`str`)
        * `value` (`str`)

      * `customOriginConfig` (`dict`) - The CloudFront custom
        origin configuration information. If an S3
        origin is required, use `s3_origin_config` instead.
        * `httpPort` (`float`) - The HTTP port the custom origin listens on.
        * `httpsPort` (`float`) - The HTTPS port the custom origin listens on.
        * `originKeepaliveTimeout` (`float`) - The Custom KeepAlive timeout, in seconds. By default, AWS enforces a limit of `60`. But you can request an [increase](http://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/RequestAndResponseBehaviorCustomOrigin.html#request-custom-request-timeout).
        * `originProtocolPolicy` (`str`) - The origin protocol policy to apply to
          your origin. One of `http-only`, `https-only`, or `match-viewer`.
        * `originReadTimeout` (`float`) - The Custom Read timeout, in seconds. By default, AWS enforces a limit of `60`. But you can request an [increase](http://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/RequestAndResponseBehaviorCustomOrigin.html#request-custom-request-timeout).
        * `originSslProtocols` (`list`) - The SSL/TLS protocols that you want
          CloudFront to use when communicating with your origin over HTTPS. A list of
          one or more of `SSLv3`, `TLSv1`, `TLSv1.1`, and `TLSv1.2`.

      * `domain_name` (`str`) - The DNS domain name of either the S3 bucket, or
        web site of your custom origin.
      * `originId` (`str`) - The unique identifier of the member origin
      * `originPath` (`str`) - An optional element that causes CloudFront to
        request your content from a directory in your Amazon S3 bucket or your
        custom origin.
      * `s3OriginConfig` (`dict`) - The CloudFront S3 origin
        configuration information. If a custom origin is required, use
        `custom_origin_config` instead.
        * `originAccessIdentity` (`str`) - The [CloudFront origin access
          identity][5] to associate with the origin.
    """
    price_class: pulumi.Output[str]
    """
    The price class for this distribution. One of
    `PriceClass_All`, `PriceClass_200`, `PriceClass_100`
    """
    restrictions: pulumi.Output[dict]
    """
    The restriction
    configuration for this distribution (maximum one).

      * `geoRestriction` (`dict`)
        * `locations` (`list`) - The [ISO 3166-1-alpha-2 codes][4] for which you
          want CloudFront either to distribute your content (`whitelist`) or not
          distribute your content (`blacklist`).
        * `restrictionType` (`str`) - The method that you want to use to restrict
          distribution of your content by country: `none`, `whitelist`, or
          `blacklist`.
    """
    retain_on_delete: pulumi.Output[bool]
    """
    Disables the distribution instead of
    deleting it when destroying the resource. If this is set,
    the distribution needs to be deleted manually afterwards. Default: `false`.
    """
    status: pulumi.Output[str]
    """
    The current status of the distribution. `Deployed` if the
    distribution's information is fully propagated throughout the Amazon
    CloudFront system.
    """
    tags: pulumi.Output[dict]
    """
    A map of tags to assign to the resource.
    """
    viewer_certificate: pulumi.Output[dict]
    """
    The SSL
    configuration for this distribution (maximum
    one).

      * `acmCertificateArn` (`str`) - The ARN of the [AWS Certificate Manager](https://aws.amazon.com/certificate-manager/)
        certificate that you wish to use with this distribution. Specify this,
        `cloudfront_default_certificate`, or `iam_certificate_id`.  The ACM
        certificate must be in  US-EAST-1.
      * `cloudfrontDefaultCertificate` (`bool`) - `true` if you want viewers to use HTTPS
        to request your objects and you're using the CloudFront domain name for your
        distribution. Specify this, `acm_certificate_arn`, or `iam_certificate_id`.
      * `iamCertificateId` (`str`) - The IAM certificate identifier of the custom viewer
        certificate for this distribution if you are using a custom domain. Specify
        this, `acm_certificate_arn`, or `cloudfront_default_certificate`.
      * `minimumProtocolVersion` (`str`) - The minimum version of the SSL protocol that
        you want CloudFront to use for HTTPS connections. Can only be set if
        `cloudfront_default_certificate = false`. One of `SSLv3`, `TLSv1`,
        `TLSv1_2016`, `TLSv1.1_2016` or `TLSv1.2_2018`. Default: `TLSv1`. **NOTE**:
        If you are using a custom certificate (specified with `acm_certificate_arn`
        or `iam_certificate_id`), and have specified `sni-only` in
        `ssl_support_method`, `TLSv1` or later must be specified. If you have
        specified `vip` in `ssl_support_method`, only `SSLv3` or `TLSv1` can be
        specified. If you have specified `cloudfront_default_certificate`, `TLSv1`
        must be specified.
      * `sslSupportMethod` (`str`)
    """
    wait_for_deployment: pulumi.Output[bool]
    """
    If enabled, the resource will wait for
    the distribution status to change from `InProgress` to `Deployed`. Setting
    this to`false` will skip the process. Default: `true`.
    """
    web_acl_id: pulumi.Output[str]
    """
    If you're using AWS WAF to filter CloudFront
    requests, the Id of the AWS WAF web ACL that is associated with the
    distribution. The WAF Web ACL must exist in the WAF Global (CloudFront)
    region and the credentials configuring this argument must have
    `waf:GetWebACL` permissions assigned.
    """
    def __init__(__self__, resource_name, opts=None, aliases=None, comment=None, custom_error_responses=None, default_cache_behavior=None, default_root_object=None, enabled=None, http_version=None, is_ipv6_enabled=None, logging_config=None, ordered_cache_behaviors=None, origin_groups=None, origins=None, price_class=None, restrictions=None, retain_on_delete=None, tags=None, viewer_certificate=None, wait_for_deployment=None, web_acl_id=None, __props__=None, __name__=None, __opts__=None):
        """
        Creates an Amazon CloudFront web distribution.

        For information about CloudFront distributions, see the
        [Amazon CloudFront Developer Guide](http://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/Introduction.html). For specific information about creating
        CloudFront web distributions, see the [POST Distribution](https://docs.aws.amazon.com/cloudfront/latest/APIReference/API_CreateDistribution.html) page in the Amazon
        CloudFront API Reference.

        > **NOTE:** CloudFront distributions take about 15 minutes to a deployed state
        after creation or modification. During this time, deletes to resources will be
        blocked. If you need to delete a distribution that is enabled and you do not
        want to wait, you need to use the `retain_on_delete` flag.

        ## Example Usage



        ```python
        import pulumi
        import pulumi_aws as aws

        bucket = aws.s3.Bucket("bucket",
            acl="private",
            tags={
                "Name": "My bucket",
            })
        s3_origin_id = "myS3Origin"
        s3_distribution = aws.cloudfront.Distribution("s3Distribution",
            aliases=[
                "mysite.example.com",
                "yoursite.example.com",
            ],
            comment="Some comment",
            default_cache_behavior={
                "allowedMethods": [
                    "DELETE",
                    "GET",
                    "HEAD",
                    "OPTIONS",
                    "PATCH",
                    "POST",
                    "PUT",
                ],
                "cachedMethods": [
                    "GET",
                    "HEAD",
                ],
                "defaultTtl": 3600,
                "forwardedValues": {
                    "cookies": {
                        "forward": "none",
                    },
                    "queryString": False,
                },
                "maxTtl": 86400,
                "minTtl": 0,
                "targetOriginId": s3_origin_id,
                "viewerProtocolPolicy": "allow-all",
            },
            default_root_object="index.html",
            enabled=True,
            is_ipv6_enabled=True,
            logging_config={
                "bucket": "mylogs.s3.amazonaws.com",
                "includeCookies": False,
                "prefix": "myprefix",
            },
            ordered_cache_behaviors=[
                {
                    "allowedMethods": [
                        "GET",
                        "HEAD",
                        "OPTIONS",
                    ],
                    "cachedMethods": [
                        "GET",
                        "HEAD",
                        "OPTIONS",
                    ],
                    "compress": True,
                    "defaultTtl": 86400,
                    "forwardedValues": {
                        "cookies": {
                            "forward": "none",
                        },
                        "headers": ["Origin"],
                        "queryString": False,
                    },
                    "maxTtl": 31536000,
                    "minTtl": 0,
                    "pathPattern": "/content/immutable/*",
                    "targetOriginId": s3_origin_id,
                    "viewerProtocolPolicy": "redirect-to-https",
                },
                {
                    "allowedMethods": [
                        "GET",
                        "HEAD",
                        "OPTIONS",
                    ],
                    "cachedMethods": [
                        "GET",
                        "HEAD",
                    ],
                    "compress": True,
                    "defaultTtl": 3600,
                    "forwardedValues": {
                        "cookies": {
                            "forward": "none",
                        },
                        "queryString": False,
                    },
                    "maxTtl": 86400,
                    "minTtl": 0,
                    "pathPattern": "/content/*",
                    "targetOriginId": s3_origin_id,
                    "viewerProtocolPolicy": "redirect-to-https",
                },
            ],
            origins=[{
                "domainName": bucket.bucket_regional_domain_name,
                "originId": s3_origin_id,
                "s3OriginConfig": {
                    "originAccessIdentity": "origin-access-identity/cloudfront/ABCDEFG1234567",
                },
            }],
            price_class="PriceClass_200",
            restrictions={
                "geoRestriction": {
                    "locations": [
                        "US",
                        "CA",
                        "GB",
                        "DE",
                    ],
                    "restrictionType": "whitelist",
                },
            },
            tags={
                "Environment": "production",
            },
            viewer_certificate={
                "cloudfrontDefaultCertificate": True,
            })
        ```


        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[list] aliases: Extra CNAMEs (alternate domain names), if any, for
               this distribution.
        :param pulumi.Input[str] comment: Any comments you want to include about the
               distribution.
        :param pulumi.Input[list] custom_error_responses: One or more custom error response elements (multiples allowed).
        :param pulumi.Input[dict] default_cache_behavior: The default cache behavior for this distribution (maximum
               one).
        :param pulumi.Input[str] default_root_object: The object that you want CloudFront to
               return (for example, index.html) when an end user requests the root URL.
        :param pulumi.Input[bool] enabled: Whether the distribution is enabled to accept end
               user requests for content.
        :param pulumi.Input[str] http_version: The maximum HTTP version to support on the
               distribution. Allowed values are `http1.1` and `http2`. The default is
               `http2`.
        :param pulumi.Input[bool] is_ipv6_enabled: Whether the IPv6 is enabled for the distribution.
        :param pulumi.Input[dict] logging_config: The logging
               configuration that controls how logs are written
               to your distribution (maximum one).
        :param pulumi.Input[list] ordered_cache_behaviors: An ordered list of cache behaviors
               resource for this distribution. List from top to bottom
               in order of precedence. The topmost cache behavior will have precedence 0.
        :param pulumi.Input[list] origin_groups: One or more origin_group for this
               distribution (multiples allowed).
        :param pulumi.Input[list] origins: One or more origins for this
               distribution (multiples allowed).
        :param pulumi.Input[str] price_class: The price class for this distribution. One of
               `PriceClass_All`, `PriceClass_200`, `PriceClass_100`
        :param pulumi.Input[dict] restrictions: The restriction
               configuration for this distribution (maximum one).
        :param pulumi.Input[bool] retain_on_delete: Disables the distribution instead of
               deleting it when destroying the resource. If this is set,
               the distribution needs to be deleted manually afterwards. Default: `false`.
        :param pulumi.Input[dict] tags: A map of tags to assign to the resource.
        :param pulumi.Input[dict] viewer_certificate: The SSL
               configuration for this distribution (maximum
               one).
        :param pulumi.Input[bool] wait_for_deployment: If enabled, the resource will wait for
               the distribution status to change from `InProgress` to `Deployed`. Setting
               this to`false` will skip the process. Default: `true`.
        :param pulumi.Input[str] web_acl_id: If you're using AWS WAF to filter CloudFront
               requests, the Id of the AWS WAF web ACL that is associated with the
               distribution. The WAF Web ACL must exist in the WAF Global (CloudFront)
               region and the credentials configuring this argument must have
               `waf:GetWebACL` permissions assigned.

        The **custom_error_responses** object supports the following:

          * `errorCachingMinTtl` (`pulumi.Input[float]`) - The minimum amount of time you want
            HTTP error codes to stay in CloudFront caches before CloudFront queries your
            origin to see whether the object has been updated.
          * `errorCode` (`pulumi.Input[float]`) - The 4xx or 5xx HTTP status code that you want to
            customize.
          * `responseCode` (`pulumi.Input[float]`) - The HTTP status code that you want CloudFront
            to return with the custom error page to the viewer.
          * `responsePagePath` (`pulumi.Input[str]`) - The path of the custom error page (for
            example, `/custom_404.html`).

        The **default_cache_behavior** object supports the following:

          * `allowedMethods` (`pulumi.Input[list]`) - Controls which HTTP methods CloudFront
            processes and forwards to your Amazon S3 bucket or your custom origin.
          * `cachedMethods` (`pulumi.Input[list]`) - Controls whether CloudFront caches the
            response to requests using the specified HTTP methods.
          * `compress` (`pulumi.Input[bool]`) - Whether you want CloudFront to automatically
            compress content for web requests that include `Accept-Encoding: gzip` in
            the request header (default: `false`).
          * `defaultTtl` (`pulumi.Input[float]`) - The default amount of time (in seconds) that an
            object is in a CloudFront cache before CloudFront forwards another request
            in the absence of an `Cache-Control max-age` or `Expires` header. Defaults to
            1 day.
          * `fieldLevelEncryptionId` (`pulumi.Input[str]`) - Field level encryption configuration ID
          * `forwardedValues` (`pulumi.Input[dict]`) - The forwarded values configuration that specifies how CloudFront
            handles query strings, cookies and headers (maximum one).
            * `cookies` (`pulumi.Input[dict]`) - The forwarded values cookies
              that specifies how CloudFront handles cookies (maximum one).
              * `forward` (`pulumi.Input[str]`) - Specifies whether you want CloudFront to forward
                cookies to the origin that is associated with this cache behavior. You can
                specify `all`, `none` or `whitelist`. If `whitelist`, you must include the
                subsequent `whitelisted_names`
              * `whitelistedNames` (`pulumi.Input[list]`) - If you have specified `whitelist` to
                `forward`, the whitelisted cookies that you want CloudFront to forward to
                your origin.

            * `headers` (`pulumi.Input[list]`) - Specifies the Headers, if any, that you want
              CloudFront to vary upon for this cache behavior. Specify `*` to include all
              headers.
            * `queryString` (`pulumi.Input[bool]`) - Indicates whether you want CloudFront to forward
              query strings to the origin that is associated with this cache behavior.
            * `queryStringCacheKeys` (`pulumi.Input[list]`) - When specified, along with a value of
              `true` for `query_string`, all query strings are forwarded, however only the
              query string keys listed in this argument are cached. When omitted with a
              value of `true` for `query_string`, all query string keys are cached.

          * `lambdaFunctionAssociations` (`pulumi.Input[list]`) - A config block that triggers a lambda function with
            specific actions. Defined below, maximum 4.
            * `eventType` (`pulumi.Input[str]`) - The specific event to trigger this function.
              Valid values: `viewer-request`, `origin-request`, `viewer-response`,
              `origin-response`
            * `includeBody` (`pulumi.Input[bool]`) - When set to true it exposes the request body to the lambda function. Defaults to false. Valid values: `true`, `false`.
            * `lambdaArn` (`pulumi.Input[str]`) - ARN of the Lambda function.

          * `maxTtl` (`pulumi.Input[float]`) - The maximum amount of time (in seconds) that an
            object is in a CloudFront cache before CloudFront forwards another request
            to your origin to determine whether the object has been updated. Only
            effective in the presence of `Cache-Control max-age`, `Cache-Control
            s-maxage`, and `Expires` headers. Defaults to 365 days.
          * `minTtl` (`pulumi.Input[float]`) - The minimum amount of time that you want objects to
            stay in CloudFront caches before CloudFront queries your origin to see
            whether the object has been updated. Defaults to 0 seconds.
          * `smoothStreaming` (`pulumi.Input[bool]`) - Indicates whether you want to distribute
            media files in Microsoft Smooth Streaming format using the origin that is
            associated with this cache behavior.
          * `targetOriginId` (`pulumi.Input[str]`) - The value of ID for the origin that you want
            CloudFront to route requests to when a request matches the path pattern
            either for a cache behavior or for the default cache behavior.
          * `trustedSigners` (`pulumi.Input[list]`) - The AWS accounts, if any, that you want to
            allow to create signed URLs for private content.
          * `viewerProtocolPolicy` (`pulumi.Input[str]`) - Use this element to specify the
            protocol that users can use to access the files in the origin specified by
            TargetOriginId when a request matches the path pattern in PathPattern. One
            of `allow-all`, `https-only`, or `redirect-to-https`.

        The **logging_config** object supports the following:

          * `bucket` (`pulumi.Input[str]`) - The Amazon S3 bucket to store the access logs in, for
            example, `myawslogbucket.s3.amazonaws.com`.
          * `includeCookies` (`pulumi.Input[bool]`) - Specifies whether you want CloudFront to
            include cookies in access logs (default: `false`).
          * `prefix` (`pulumi.Input[str]`) - An optional string that you want CloudFront to prefix
            to the access log filenames for this distribution, for example, `myprefix/`.

        The **ordered_cache_behaviors** object supports the following:

          * `allowedMethods` (`pulumi.Input[list]`) - Controls which HTTP methods CloudFront
            processes and forwards to your Amazon S3 bucket or your custom origin.
          * `cachedMethods` (`pulumi.Input[list]`) - Controls whether CloudFront caches the
            response to requests using the specified HTTP methods.
          * `compress` (`pulumi.Input[bool]`) - Whether you want CloudFront to automatically
            compress content for web requests that include `Accept-Encoding: gzip` in
            the request header (default: `false`).
          * `defaultTtl` (`pulumi.Input[float]`) - The default amount of time (in seconds) that an
            object is in a CloudFront cache before CloudFront forwards another request
            in the absence of an `Cache-Control max-age` or `Expires` header. Defaults to
            1 day.
          * `fieldLevelEncryptionId` (`pulumi.Input[str]`) - Field level encryption configuration ID
          * `forwardedValues` (`pulumi.Input[dict]`) - The forwarded values configuration that specifies how CloudFront
            handles query strings, cookies and headers (maximum one).
            * `cookies` (`pulumi.Input[dict]`) - The forwarded values cookies
              that specifies how CloudFront handles cookies (maximum one).
              * `forward` (`pulumi.Input[str]`) - Specifies whether you want CloudFront to forward
                cookies to the origin that is associated with this cache behavior. You can
                specify `all`, `none` or `whitelist`. If `whitelist`, you must include the
                subsequent `whitelisted_names`
              * `whitelistedNames` (`pulumi.Input[list]`) - If you have specified `whitelist` to
                `forward`, the whitelisted cookies that you want CloudFront to forward to
                your origin.

            * `headers` (`pulumi.Input[list]`) - Specifies the Headers, if any, that you want
              CloudFront to vary upon for this cache behavior. Specify `*` to include all
              headers.
            * `queryString` (`pulumi.Input[bool]`) - Indicates whether you want CloudFront to forward
              query strings to the origin that is associated with this cache behavior.
            * `queryStringCacheKeys` (`pulumi.Input[list]`) - When specified, along with a value of
              `true` for `query_string`, all query strings are forwarded, however only the
              query string keys listed in this argument are cached. When omitted with a
              value of `true` for `query_string`, all query string keys are cached.

          * `lambdaFunctionAssociations` (`pulumi.Input[list]`) - A config block that triggers a lambda function with
            specific actions. Defined below, maximum 4.
            * `eventType` (`pulumi.Input[str]`) - The specific event to trigger this function.
              Valid values: `viewer-request`, `origin-request`, `viewer-response`,
              `origin-response`
            * `includeBody` (`pulumi.Input[bool]`) - When set to true it exposes the request body to the lambda function. Defaults to false. Valid values: `true`, `false`.
            * `lambdaArn` (`pulumi.Input[str]`) - ARN of the Lambda function.

          * `maxTtl` (`pulumi.Input[float]`) - The maximum amount of time (in seconds) that an
            object is in a CloudFront cache before CloudFront forwards another request
            to your origin to determine whether the object has been updated. Only
            effective in the presence of `Cache-Control max-age`, `Cache-Control
            s-maxage`, and `Expires` headers. Defaults to 365 days.
          * `minTtl` (`pulumi.Input[float]`) - The minimum amount of time that you want objects to
            stay in CloudFront caches before CloudFront queries your origin to see
            whether the object has been updated. Defaults to 0 seconds.
          * `pathPattern` (`pulumi.Input[str]`) - The pattern (for example, `images/*.jpg)` that
            specifies which requests you want this cache behavior to apply to.
          * `smoothStreaming` (`pulumi.Input[bool]`) - Indicates whether you want to distribute
            media files in Microsoft Smooth Streaming format using the origin that is
            associated with this cache behavior.
          * `targetOriginId` (`pulumi.Input[str]`) - The value of ID for the origin that you want
            CloudFront to route requests to when a request matches the path pattern
            either for a cache behavior or for the default cache behavior.
          * `trustedSigners` (`pulumi.Input[list]`) - The AWS accounts, if any, that you want to
            allow to create signed URLs for private content.
          * `viewerProtocolPolicy` (`pulumi.Input[str]`) - Use this element to specify the
            protocol that users can use to access the files in the origin specified by
            TargetOriginId when a request matches the path pattern in PathPattern. One
            of `allow-all`, `https-only`, or `redirect-to-https`.

        The **origin_groups** object supports the following:

          * `failoverCriteria` (`pulumi.Input[dict]`) - The failover criteria for when to failover to the secondary origin
            * `statusCodes` (`pulumi.Input[list]`) - A list of HTTP status codes for the origin group

          * `members` (`pulumi.Input[list]`) - Ordered member configuration blocks assigned to the origin group, where the first member is the primary origin. You must specify two members.
            * `originId` (`pulumi.Input[str]`) - The unique identifier of the member origin

          * `originId` (`pulumi.Input[str]`) - The unique identifier of the member origin

        The **origins** object supports the following:

          * `customHeaders` (`pulumi.Input[list]`) - One or more sub-resources with `name` and
            `value` parameters that specify header data that will be sent to the origin
            (multiples allowed).
            * `name` (`pulumi.Input[str]`)
            * `value` (`pulumi.Input[str]`)

          * `customOriginConfig` (`pulumi.Input[dict]`) - The CloudFront custom
            origin configuration information. If an S3
            origin is required, use `s3_origin_config` instead.
            * `httpPort` (`pulumi.Input[float]`) - The HTTP port the custom origin listens on.
            * `httpsPort` (`pulumi.Input[float]`) - The HTTPS port the custom origin listens on.
            * `originKeepaliveTimeout` (`pulumi.Input[float]`) - The Custom KeepAlive timeout, in seconds. By default, AWS enforces a limit of `60`. But you can request an [increase](http://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/RequestAndResponseBehaviorCustomOrigin.html#request-custom-request-timeout).
            * `originProtocolPolicy` (`pulumi.Input[str]`) - The origin protocol policy to apply to
              your origin. One of `http-only`, `https-only`, or `match-viewer`.
            * `originReadTimeout` (`pulumi.Input[float]`) - The Custom Read timeout, in seconds. By default, AWS enforces a limit of `60`. But you can request an [increase](http://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/RequestAndResponseBehaviorCustomOrigin.html#request-custom-request-timeout).
            * `originSslProtocols` (`pulumi.Input[list]`) - The SSL/TLS protocols that you want
              CloudFront to use when communicating with your origin over HTTPS. A list of
              one or more of `SSLv3`, `TLSv1`, `TLSv1.1`, and `TLSv1.2`.

          * `domain_name` (`pulumi.Input[str]`) - The DNS domain name of either the S3 bucket, or
            web site of your custom origin.
          * `originId` (`pulumi.Input[str]`) - The unique identifier of the member origin
          * `originPath` (`pulumi.Input[str]`) - An optional element that causes CloudFront to
            request your content from a directory in your Amazon S3 bucket or your
            custom origin.
          * `s3OriginConfig` (`pulumi.Input[dict]`) - The CloudFront S3 origin
            configuration information. If a custom origin is required, use
            `custom_origin_config` instead.
            * `originAccessIdentity` (`pulumi.Input[str]`) - The [CloudFront origin access
              identity][5] to associate with the origin.

        The **restrictions** object supports the following:

          * `geoRestriction` (`pulumi.Input[dict]`)
            * `locations` (`pulumi.Input[list]`) - The [ISO 3166-1-alpha-2 codes][4] for which you
              want CloudFront either to distribute your content (`whitelist`) or not
              distribute your content (`blacklist`).
            * `restrictionType` (`pulumi.Input[str]`) - The method that you want to use to restrict
              distribution of your content by country: `none`, `whitelist`, or
              `blacklist`.

        The **viewer_certificate** object supports the following:

          * `acmCertificateArn` (`pulumi.Input[str]`) - The ARN of the [AWS Certificate Manager](https://aws.amazon.com/certificate-manager/)
            certificate that you wish to use with this distribution. Specify this,
            `cloudfront_default_certificate`, or `iam_certificate_id`.  The ACM
            certificate must be in  US-EAST-1.
          * `cloudfrontDefaultCertificate` (`pulumi.Input[bool]`) - `true` if you want viewers to use HTTPS
            to request your objects and you're using the CloudFront domain name for your
            distribution. Specify this, `acm_certificate_arn`, or `iam_certificate_id`.
          * `iamCertificateId` (`pulumi.Input[str]`) - The IAM certificate identifier of the custom viewer
            certificate for this distribution if you are using a custom domain. Specify
            this, `acm_certificate_arn`, or `cloudfront_default_certificate`.
          * `minimumProtocolVersion` (`pulumi.Input[str]`) - The minimum version of the SSL protocol that
            you want CloudFront to use for HTTPS connections. Can only be set if
            `cloudfront_default_certificate = false`. One of `SSLv3`, `TLSv1`,
            `TLSv1_2016`, `TLSv1.1_2016` or `TLSv1.2_2018`. Default: `TLSv1`. **NOTE**:
            If you are using a custom certificate (specified with `acm_certificate_arn`
            or `iam_certificate_id`), and have specified `sni-only` in
            `ssl_support_method`, `TLSv1` or later must be specified. If you have
            specified `vip` in `ssl_support_method`, only `SSLv3` or `TLSv1` can be
            specified. If you have specified `cloudfront_default_certificate`, `TLSv1`
            must be specified.
          * `sslSupportMethod` (`pulumi.Input[str]`)
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            __props__['aliases'] = aliases
            __props__['comment'] = comment
            __props__['custom_error_responses'] = custom_error_responses
            if default_cache_behavior is None:
                raise TypeError("Missing required property 'default_cache_behavior'")
            __props__['default_cache_behavior'] = default_cache_behavior
            __props__['default_root_object'] = default_root_object
            if enabled is None:
                raise TypeError("Missing required property 'enabled'")
            __props__['enabled'] = enabled
            __props__['http_version'] = http_version
            __props__['is_ipv6_enabled'] = is_ipv6_enabled
            __props__['logging_config'] = logging_config
            __props__['ordered_cache_behaviors'] = ordered_cache_behaviors
            __props__['origin_groups'] = origin_groups
            if origins is None:
                raise TypeError("Missing required property 'origins'")
            __props__['origins'] = origins
            __props__['price_class'] = price_class
            if restrictions is None:
                raise TypeError("Missing required property 'restrictions'")
            __props__['restrictions'] = restrictions
            __props__['retain_on_delete'] = retain_on_delete
            __props__['tags'] = tags
            if viewer_certificate is None:
                raise TypeError("Missing required property 'viewer_certificate'")
            __props__['viewer_certificate'] = viewer_certificate
            __props__['wait_for_deployment'] = wait_for_deployment
            __props__['web_acl_id'] = web_acl_id
            __props__['active_trusted_signers'] = None
            __props__['arn'] = None
            __props__['caller_reference'] = None
            __props__['domain_name'] = None
            __props__['etag'] = None
            __props__['hosted_zone_id'] = None
            __props__['in_progress_validation_batches'] = None
            __props__['last_modified_time'] = None
            __props__['status'] = None
        super(Distribution, __self__).__init__(
            'aws:cloudfront/distribution:Distribution',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, active_trusted_signers=None, aliases=None, arn=None, caller_reference=None, comment=None, custom_error_responses=None, default_cache_behavior=None, default_root_object=None, domain_name=None, enabled=None, etag=None, hosted_zone_id=None, http_version=None, in_progress_validation_batches=None, is_ipv6_enabled=None, last_modified_time=None, logging_config=None, ordered_cache_behaviors=None, origin_groups=None, origins=None, price_class=None, restrictions=None, retain_on_delete=None, status=None, tags=None, viewer_certificate=None, wait_for_deployment=None, web_acl_id=None):
        """
        Get an existing Distribution resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[dict] active_trusted_signers: The key pair IDs that CloudFront is aware of for
               each trusted signer, if the distribution is set up to serve private content
               with signed URLs.
        :param pulumi.Input[list] aliases: Extra CNAMEs (alternate domain names), if any, for
               this distribution.
        :param pulumi.Input[str] arn: The ARN (Amazon Resource Name) for the distribution. For example: arn:aws:cloudfront::123456789012:distribution/EDFDVBD632BHDS5, where 123456789012 is your AWS account ID.
        :param pulumi.Input[str] caller_reference: Internal value used by CloudFront to allow future
               updates to the distribution configuration.
        :param pulumi.Input[str] comment: Any comments you want to include about the
               distribution.
        :param pulumi.Input[list] custom_error_responses: One or more custom error response elements (multiples allowed).
        :param pulumi.Input[dict] default_cache_behavior: The default cache behavior for this distribution (maximum
               one).
        :param pulumi.Input[str] default_root_object: The object that you want CloudFront to
               return (for example, index.html) when an end user requests the root URL.
        :param pulumi.Input[str] domain_name: The DNS domain name of either the S3 bucket, or
               web site of your custom origin.
        :param pulumi.Input[bool] enabled: Whether the distribution is enabled to accept end
               user requests for content.
        :param pulumi.Input[str] etag: The current version of the distribution's information. For example:
               `E2QWRUHAPOMQZL`.
        :param pulumi.Input[str] hosted_zone_id: The CloudFront Route 53 zone ID that can be used to
               route an [Alias Resource Record Set](http://docs.aws.amazon.com/Route53/latest/APIReference/CreateAliasRRSAPI.html) to. This attribute is simply an
               alias for the zone ID `Z2FDTNDATAQYW2`.
        :param pulumi.Input[str] http_version: The maximum HTTP version to support on the
               distribution. Allowed values are `http1.1` and `http2`. The default is
               `http2`.
        :param pulumi.Input[float] in_progress_validation_batches: The number of invalidation batches
               currently in progress.
        :param pulumi.Input[bool] is_ipv6_enabled: Whether the IPv6 is enabled for the distribution.
        :param pulumi.Input[str] last_modified_time: The date and time the distribution was last modified.
        :param pulumi.Input[dict] logging_config: The logging
               configuration that controls how logs are written
               to your distribution (maximum one).
        :param pulumi.Input[list] ordered_cache_behaviors: An ordered list of cache behaviors
               resource for this distribution. List from top to bottom
               in order of precedence. The topmost cache behavior will have precedence 0.
        :param pulumi.Input[list] origin_groups: One or more origin_group for this
               distribution (multiples allowed).
        :param pulumi.Input[list] origins: One or more origins for this
               distribution (multiples allowed).
        :param pulumi.Input[str] price_class: The price class for this distribution. One of
               `PriceClass_All`, `PriceClass_200`, `PriceClass_100`
        :param pulumi.Input[dict] restrictions: The restriction
               configuration for this distribution (maximum one).
        :param pulumi.Input[bool] retain_on_delete: Disables the distribution instead of
               deleting it when destroying the resource. If this is set,
               the distribution needs to be deleted manually afterwards. Default: `false`.
        :param pulumi.Input[str] status: The current status of the distribution. `Deployed` if the
               distribution's information is fully propagated throughout the Amazon
               CloudFront system.
        :param pulumi.Input[dict] tags: A map of tags to assign to the resource.
        :param pulumi.Input[dict] viewer_certificate: The SSL
               configuration for this distribution (maximum
               one).
        :param pulumi.Input[bool] wait_for_deployment: If enabled, the resource will wait for
               the distribution status to change from `InProgress` to `Deployed`. Setting
               this to`false` will skip the process. Default: `true`.
        :param pulumi.Input[str] web_acl_id: If you're using AWS WAF to filter CloudFront
               requests, the Id of the AWS WAF web ACL that is associated with the
               distribution. The WAF Web ACL must exist in the WAF Global (CloudFront)
               region and the credentials configuring this argument must have
               `waf:GetWebACL` permissions assigned.

        The **custom_error_responses** object supports the following:

          * `errorCachingMinTtl` (`pulumi.Input[float]`) - The minimum amount of time you want
            HTTP error codes to stay in CloudFront caches before CloudFront queries your
            origin to see whether the object has been updated.
          * `errorCode` (`pulumi.Input[float]`) - The 4xx or 5xx HTTP status code that you want to
            customize.
          * `responseCode` (`pulumi.Input[float]`) - The HTTP status code that you want CloudFront
            to return with the custom error page to the viewer.
          * `responsePagePath` (`pulumi.Input[str]`) - The path of the custom error page (for
            example, `/custom_404.html`).

        The **default_cache_behavior** object supports the following:

          * `allowedMethods` (`pulumi.Input[list]`) - Controls which HTTP methods CloudFront
            processes and forwards to your Amazon S3 bucket or your custom origin.
          * `cachedMethods` (`pulumi.Input[list]`) - Controls whether CloudFront caches the
            response to requests using the specified HTTP methods.
          * `compress` (`pulumi.Input[bool]`) - Whether you want CloudFront to automatically
            compress content for web requests that include `Accept-Encoding: gzip` in
            the request header (default: `false`).
          * `defaultTtl` (`pulumi.Input[float]`) - The default amount of time (in seconds) that an
            object is in a CloudFront cache before CloudFront forwards another request
            in the absence of an `Cache-Control max-age` or `Expires` header. Defaults to
            1 day.
          * `fieldLevelEncryptionId` (`pulumi.Input[str]`) - Field level encryption configuration ID
          * `forwardedValues` (`pulumi.Input[dict]`) - The forwarded values configuration that specifies how CloudFront
            handles query strings, cookies and headers (maximum one).
            * `cookies` (`pulumi.Input[dict]`) - The forwarded values cookies
              that specifies how CloudFront handles cookies (maximum one).
              * `forward` (`pulumi.Input[str]`) - Specifies whether you want CloudFront to forward
                cookies to the origin that is associated with this cache behavior. You can
                specify `all`, `none` or `whitelist`. If `whitelist`, you must include the
                subsequent `whitelisted_names`
              * `whitelistedNames` (`pulumi.Input[list]`) - If you have specified `whitelist` to
                `forward`, the whitelisted cookies that you want CloudFront to forward to
                your origin.

            * `headers` (`pulumi.Input[list]`) - Specifies the Headers, if any, that you want
              CloudFront to vary upon for this cache behavior. Specify `*` to include all
              headers.
            * `queryString` (`pulumi.Input[bool]`) - Indicates whether you want CloudFront to forward
              query strings to the origin that is associated with this cache behavior.
            * `queryStringCacheKeys` (`pulumi.Input[list]`) - When specified, along with a value of
              `true` for `query_string`, all query strings are forwarded, however only the
              query string keys listed in this argument are cached. When omitted with a
              value of `true` for `query_string`, all query string keys are cached.

          * `lambdaFunctionAssociations` (`pulumi.Input[list]`) - A config block that triggers a lambda function with
            specific actions. Defined below, maximum 4.
            * `eventType` (`pulumi.Input[str]`) - The specific event to trigger this function.
              Valid values: `viewer-request`, `origin-request`, `viewer-response`,
              `origin-response`
            * `includeBody` (`pulumi.Input[bool]`) - When set to true it exposes the request body to the lambda function. Defaults to false. Valid values: `true`, `false`.
            * `lambdaArn` (`pulumi.Input[str]`) - ARN of the Lambda function.

          * `maxTtl` (`pulumi.Input[float]`) - The maximum amount of time (in seconds) that an
            object is in a CloudFront cache before CloudFront forwards another request
            to your origin to determine whether the object has been updated. Only
            effective in the presence of `Cache-Control max-age`, `Cache-Control
            s-maxage`, and `Expires` headers. Defaults to 365 days.
          * `minTtl` (`pulumi.Input[float]`) - The minimum amount of time that you want objects to
            stay in CloudFront caches before CloudFront queries your origin to see
            whether the object has been updated. Defaults to 0 seconds.
          * `smoothStreaming` (`pulumi.Input[bool]`) - Indicates whether you want to distribute
            media files in Microsoft Smooth Streaming format using the origin that is
            associated with this cache behavior.
          * `targetOriginId` (`pulumi.Input[str]`) - The value of ID for the origin that you want
            CloudFront to route requests to when a request matches the path pattern
            either for a cache behavior or for the default cache behavior.
          * `trustedSigners` (`pulumi.Input[list]`) - The AWS accounts, if any, that you want to
            allow to create signed URLs for private content.
          * `viewerProtocolPolicy` (`pulumi.Input[str]`) - Use this element to specify the
            protocol that users can use to access the files in the origin specified by
            TargetOriginId when a request matches the path pattern in PathPattern. One
            of `allow-all`, `https-only`, or `redirect-to-https`.

        The **logging_config** object supports the following:

          * `bucket` (`pulumi.Input[str]`) - The Amazon S3 bucket to store the access logs in, for
            example, `myawslogbucket.s3.amazonaws.com`.
          * `includeCookies` (`pulumi.Input[bool]`) - Specifies whether you want CloudFront to
            include cookies in access logs (default: `false`).
          * `prefix` (`pulumi.Input[str]`) - An optional string that you want CloudFront to prefix
            to the access log filenames for this distribution, for example, `myprefix/`.

        The **ordered_cache_behaviors** object supports the following:

          * `allowedMethods` (`pulumi.Input[list]`) - Controls which HTTP methods CloudFront
            processes and forwards to your Amazon S3 bucket or your custom origin.
          * `cachedMethods` (`pulumi.Input[list]`) - Controls whether CloudFront caches the
            response to requests using the specified HTTP methods.
          * `compress` (`pulumi.Input[bool]`) - Whether you want CloudFront to automatically
            compress content for web requests that include `Accept-Encoding: gzip` in
            the request header (default: `false`).
          * `defaultTtl` (`pulumi.Input[float]`) - The default amount of time (in seconds) that an
            object is in a CloudFront cache before CloudFront forwards another request
            in the absence of an `Cache-Control max-age` or `Expires` header. Defaults to
            1 day.
          * `fieldLevelEncryptionId` (`pulumi.Input[str]`) - Field level encryption configuration ID
          * `forwardedValues` (`pulumi.Input[dict]`) - The forwarded values configuration that specifies how CloudFront
            handles query strings, cookies and headers (maximum one).
            * `cookies` (`pulumi.Input[dict]`) - The forwarded values cookies
              that specifies how CloudFront handles cookies (maximum one).
              * `forward` (`pulumi.Input[str]`) - Specifies whether you want CloudFront to forward
                cookies to the origin that is associated with this cache behavior. You can
                specify `all`, `none` or `whitelist`. If `whitelist`, you must include the
                subsequent `whitelisted_names`
              * `whitelistedNames` (`pulumi.Input[list]`) - If you have specified `whitelist` to
                `forward`, the whitelisted cookies that you want CloudFront to forward to
                your origin.

            * `headers` (`pulumi.Input[list]`) - Specifies the Headers, if any, that you want
              CloudFront to vary upon for this cache behavior. Specify `*` to include all
              headers.
            * `queryString` (`pulumi.Input[bool]`) - Indicates whether you want CloudFront to forward
              query strings to the origin that is associated with this cache behavior.
            * `queryStringCacheKeys` (`pulumi.Input[list]`) - When specified, along with a value of
              `true` for `query_string`, all query strings are forwarded, however only the
              query string keys listed in this argument are cached. When omitted with a
              value of `true` for `query_string`, all query string keys are cached.

          * `lambdaFunctionAssociations` (`pulumi.Input[list]`) - A config block that triggers a lambda function with
            specific actions. Defined below, maximum 4.
            * `eventType` (`pulumi.Input[str]`) - The specific event to trigger this function.
              Valid values: `viewer-request`, `origin-request`, `viewer-response`,
              `origin-response`
            * `includeBody` (`pulumi.Input[bool]`) - When set to true it exposes the request body to the lambda function. Defaults to false. Valid values: `true`, `false`.
            * `lambdaArn` (`pulumi.Input[str]`) - ARN of the Lambda function.

          * `maxTtl` (`pulumi.Input[float]`) - The maximum amount of time (in seconds) that an
            object is in a CloudFront cache before CloudFront forwards another request
            to your origin to determine whether the object has been updated. Only
            effective in the presence of `Cache-Control max-age`, `Cache-Control
            s-maxage`, and `Expires` headers. Defaults to 365 days.
          * `minTtl` (`pulumi.Input[float]`) - The minimum amount of time that you want objects to
            stay in CloudFront caches before CloudFront queries your origin to see
            whether the object has been updated. Defaults to 0 seconds.
          * `pathPattern` (`pulumi.Input[str]`) - The pattern (for example, `images/*.jpg)` that
            specifies which requests you want this cache behavior to apply to.
          * `smoothStreaming` (`pulumi.Input[bool]`) - Indicates whether you want to distribute
            media files in Microsoft Smooth Streaming format using the origin that is
            associated with this cache behavior.
          * `targetOriginId` (`pulumi.Input[str]`) - The value of ID for the origin that you want
            CloudFront to route requests to when a request matches the path pattern
            either for a cache behavior or for the default cache behavior.
          * `trustedSigners` (`pulumi.Input[list]`) - The AWS accounts, if any, that you want to
            allow to create signed URLs for private content.
          * `viewerProtocolPolicy` (`pulumi.Input[str]`) - Use this element to specify the
            protocol that users can use to access the files in the origin specified by
            TargetOriginId when a request matches the path pattern in PathPattern. One
            of `allow-all`, `https-only`, or `redirect-to-https`.

        The **origin_groups** object supports the following:

          * `failoverCriteria` (`pulumi.Input[dict]`) - The failover criteria for when to failover to the secondary origin
            * `statusCodes` (`pulumi.Input[list]`) - A list of HTTP status codes for the origin group

          * `members` (`pulumi.Input[list]`) - Ordered member configuration blocks assigned to the origin group, where the first member is the primary origin. You must specify two members.
            * `originId` (`pulumi.Input[str]`) - The unique identifier of the member origin

          * `originId` (`pulumi.Input[str]`) - The unique identifier of the member origin

        The **origins** object supports the following:

          * `customHeaders` (`pulumi.Input[list]`) - One or more sub-resources with `name` and
            `value` parameters that specify header data that will be sent to the origin
            (multiples allowed).
            * `name` (`pulumi.Input[str]`)
            * `value` (`pulumi.Input[str]`)

          * `customOriginConfig` (`pulumi.Input[dict]`) - The CloudFront custom
            origin configuration information. If an S3
            origin is required, use `s3_origin_config` instead.
            * `httpPort` (`pulumi.Input[float]`) - The HTTP port the custom origin listens on.
            * `httpsPort` (`pulumi.Input[float]`) - The HTTPS port the custom origin listens on.
            * `originKeepaliveTimeout` (`pulumi.Input[float]`) - The Custom KeepAlive timeout, in seconds. By default, AWS enforces a limit of `60`. But you can request an [increase](http://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/RequestAndResponseBehaviorCustomOrigin.html#request-custom-request-timeout).
            * `originProtocolPolicy` (`pulumi.Input[str]`) - The origin protocol policy to apply to
              your origin. One of `http-only`, `https-only`, or `match-viewer`.
            * `originReadTimeout` (`pulumi.Input[float]`) - The Custom Read timeout, in seconds. By default, AWS enforces a limit of `60`. But you can request an [increase](http://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/RequestAndResponseBehaviorCustomOrigin.html#request-custom-request-timeout).
            * `originSslProtocols` (`pulumi.Input[list]`) - The SSL/TLS protocols that you want
              CloudFront to use when communicating with your origin over HTTPS. A list of
              one or more of `SSLv3`, `TLSv1`, `TLSv1.1`, and `TLSv1.2`.

          * `domain_name` (`pulumi.Input[str]`) - The DNS domain name of either the S3 bucket, or
            web site of your custom origin.
          * `originId` (`pulumi.Input[str]`) - The unique identifier of the member origin
          * `originPath` (`pulumi.Input[str]`) - An optional element that causes CloudFront to
            request your content from a directory in your Amazon S3 bucket or your
            custom origin.
          * `s3OriginConfig` (`pulumi.Input[dict]`) - The CloudFront S3 origin
            configuration information. If a custom origin is required, use
            `custom_origin_config` instead.
            * `originAccessIdentity` (`pulumi.Input[str]`) - The [CloudFront origin access
              identity][5] to associate with the origin.

        The **restrictions** object supports the following:

          * `geoRestriction` (`pulumi.Input[dict]`)
            * `locations` (`pulumi.Input[list]`) - The [ISO 3166-1-alpha-2 codes][4] for which you
              want CloudFront either to distribute your content (`whitelist`) or not
              distribute your content (`blacklist`).
            * `restrictionType` (`pulumi.Input[str]`) - The method that you want to use to restrict
              distribution of your content by country: `none`, `whitelist`, or
              `blacklist`.

        The **viewer_certificate** object supports the following:

          * `acmCertificateArn` (`pulumi.Input[str]`) - The ARN of the [AWS Certificate Manager](https://aws.amazon.com/certificate-manager/)
            certificate that you wish to use with this distribution. Specify this,
            `cloudfront_default_certificate`, or `iam_certificate_id`.  The ACM
            certificate must be in  US-EAST-1.
          * `cloudfrontDefaultCertificate` (`pulumi.Input[bool]`) - `true` if you want viewers to use HTTPS
            to request your objects and you're using the CloudFront domain name for your
            distribution. Specify this, `acm_certificate_arn`, or `iam_certificate_id`.
          * `iamCertificateId` (`pulumi.Input[str]`) - The IAM certificate identifier of the custom viewer
            certificate for this distribution if you are using a custom domain. Specify
            this, `acm_certificate_arn`, or `cloudfront_default_certificate`.
          * `minimumProtocolVersion` (`pulumi.Input[str]`) - The minimum version of the SSL protocol that
            you want CloudFront to use for HTTPS connections. Can only be set if
            `cloudfront_default_certificate = false`. One of `SSLv3`, `TLSv1`,
            `TLSv1_2016`, `TLSv1.1_2016` or `TLSv1.2_2018`. Default: `TLSv1`. **NOTE**:
            If you are using a custom certificate (specified with `acm_certificate_arn`
            or `iam_certificate_id`), and have specified `sni-only` in
            `ssl_support_method`, `TLSv1` or later must be specified. If you have
            specified `vip` in `ssl_support_method`, only `SSLv3` or `TLSv1` can be
            specified. If you have specified `cloudfront_default_certificate`, `TLSv1`
            must be specified.
          * `sslSupportMethod` (`pulumi.Input[str]`)
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()

        __props__["active_trusted_signers"] = active_trusted_signers
        __props__["aliases"] = aliases
        __props__["arn"] = arn
        __props__["caller_reference"] = caller_reference
        __props__["comment"] = comment
        __props__["custom_error_responses"] = custom_error_responses
        __props__["default_cache_behavior"] = default_cache_behavior
        __props__["default_root_object"] = default_root_object
        __props__["domain_name"] = domain_name
        __props__["enabled"] = enabled
        __props__["etag"] = etag
        __props__["hosted_zone_id"] = hosted_zone_id
        __props__["http_version"] = http_version
        __props__["in_progress_validation_batches"] = in_progress_validation_batches
        __props__["is_ipv6_enabled"] = is_ipv6_enabled
        __props__["last_modified_time"] = last_modified_time
        __props__["logging_config"] = logging_config
        __props__["ordered_cache_behaviors"] = ordered_cache_behaviors
        __props__["origin_groups"] = origin_groups
        __props__["origins"] = origins
        __props__["price_class"] = price_class
        __props__["restrictions"] = restrictions
        __props__["retain_on_delete"] = retain_on_delete
        __props__["status"] = status
        __props__["tags"] = tags
        __props__["viewer_certificate"] = viewer_certificate
        __props__["wait_for_deployment"] = wait_for_deployment
        __props__["web_acl_id"] = web_acl_id
        return Distribution(resource_name, opts=opts, __props__=__props__)
    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables

class Zone(pulumi.CustomResource):
    comment: pulumi.Output[str]
    """
    A comment for the hosted zone. Defaults to 'Managed by Pulumi'.
    """
    delegation_set_id: pulumi.Output[str]
    """
    The ID of the reusable delegation set whose NS records you want to assign to the hosted zone. Conflicts with `vpc` as delegation sets can only be used for public zones.
    """
    force_destroy: pulumi.Output[bool]
    """
    Whether to destroy all records (possibly managed outside of this provider) in the zone when destroying the zone.
    """
    name: pulumi.Output[str]
    """
    This is the name of the hosted zone.
    """
    name_servers: pulumi.Output[list]
    """
    A list of name servers in associated (or default) delegation set.
    Find more about delegation sets in [AWS docs](https://docs.aws.amazon.com/Route53/latest/APIReference/actions-on-reusable-delegation-sets.html).
    """
    tags: pulumi.Output[dict]
    """
    A mapping of tags to assign to the zone.
    """
    vpcs: pulumi.Output[list]
    """
    Configuration block(s) specifying VPC(s) to associate with a private hosted zone. Conflicts with the `delegation_set_id` argument in this resource and any [`route53.ZoneAssociation` resource](https://www.terraform.io/docs/providers/aws/r/route53_zone_association.html) specifying the same zone ID. Detailed below.

      * `vpc_id` (`str`) - ID of the VPC to associate.
      * `vpc_region` (`str`) - Region of the VPC to associate. Defaults to AWS provider region.
    """
    zone_id: pulumi.Output[str]
    """
    The Hosted Zone ID. This can be referenced by zone records.
    """
    def __init__(__self__, resource_name, opts=None, comment=None, delegation_set_id=None, force_destroy=None, name=None, tags=None, vpcs=None, __props__=None, __name__=None, __opts__=None):
        """
        Manages a Route53 Hosted Zone.

        ## Example Usage

        ### Public Zone

        ```python
        import pulumi
        import pulumi_aws as aws

        primary = aws.route53.Zone("primary")
        ```

        ### Public Subdomain Zone

        ```python
        import pulumi
        import pulumi_aws as aws

        main = aws.route53.Zone("main")
        dev = aws.route53.Zone("dev", tags={
            "Environment": "dev",
        })
        dev_ns = aws.route53.Record("dev-ns",
            name="dev.example.com",
            records=[
                dev.name_servers[0],
                dev.name_servers[1],
                dev.name_servers[2],
                dev.name_servers[3],
            ],
            ttl="30",
            type="NS",
            zone_id=main.zone_id)
        ```

        ### Private Zone

        ```python
        import pulumi
        import pulumi_aws as aws

        private = aws.route53.Zone("private", vpcs=[{
            "vpcId": aws_vpc["example"]["id"],
        }])
        ```


        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] comment: A comment for the hosted zone. Defaults to 'Managed by Pulumi'.
        :param pulumi.Input[str] delegation_set_id: The ID of the reusable delegation set whose NS records you want to assign to the hosted zone. Conflicts with `vpc` as delegation sets can only be used for public zones.
        :param pulumi.Input[bool] force_destroy: Whether to destroy all records (possibly managed outside of this provider) in the zone when destroying the zone.
        :param pulumi.Input[str] name: This is the name of the hosted zone.
        :param pulumi.Input[dict] tags: A mapping of tags to assign to the zone.
        :param pulumi.Input[list] vpcs: Configuration block(s) specifying VPC(s) to associate with a private hosted zone. Conflicts with the `delegation_set_id` argument in this resource and any [`route53.ZoneAssociation` resource](https://www.terraform.io/docs/providers/aws/r/route53_zone_association.html) specifying the same zone ID. Detailed below.

        The **vpcs** object supports the following:

          * `vpc_id` (`pulumi.Input[str]`) - ID of the VPC to associate.
          * `vpc_region` (`pulumi.Input[str]`) - Region of the VPC to associate. Defaults to AWS provider region.
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            if comment is None:
                comment = 'Managed by Pulumi'
            __props__['comment'] = comment
            __props__['delegation_set_id'] = delegation_set_id
            __props__['force_destroy'] = force_destroy
            __props__['name'] = name
            __props__['tags'] = tags
            __props__['vpcs'] = vpcs
            __props__['name_servers'] = None
            __props__['zone_id'] = None
        super(Zone, __self__).__init__(
            'aws:route53/zone:Zone',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, comment=None, delegation_set_id=None, force_destroy=None, name=None, name_servers=None, tags=None, vpcs=None, zone_id=None):
        """
        Get an existing Zone resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] comment: A comment for the hosted zone. Defaults to 'Managed by Pulumi'.
        :param pulumi.Input[str] delegation_set_id: The ID of the reusable delegation set whose NS records you want to assign to the hosted zone. Conflicts with `vpc` as delegation sets can only be used for public zones.
        :param pulumi.Input[bool] force_destroy: Whether to destroy all records (possibly managed outside of this provider) in the zone when destroying the zone.
        :param pulumi.Input[str] name: This is the name of the hosted zone.
        :param pulumi.Input[list] name_servers: A list of name servers in associated (or default) delegation set.
               Find more about delegation sets in [AWS docs](https://docs.aws.amazon.com/Route53/latest/APIReference/actions-on-reusable-delegation-sets.html).
        :param pulumi.Input[dict] tags: A mapping of tags to assign to the zone.
        :param pulumi.Input[list] vpcs: Configuration block(s) specifying VPC(s) to associate with a private hosted zone. Conflicts with the `delegation_set_id` argument in this resource and any [`route53.ZoneAssociation` resource](https://www.terraform.io/docs/providers/aws/r/route53_zone_association.html) specifying the same zone ID. Detailed below.
        :param pulumi.Input[str] zone_id: The Hosted Zone ID. This can be referenced by zone records.

        The **vpcs** object supports the following:

          * `vpc_id` (`pulumi.Input[str]`) - ID of the VPC to associate.
          * `vpc_region` (`pulumi.Input[str]`) - Region of the VPC to associate. Defaults to AWS provider region.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()

        __props__["comment"] = comment
        __props__["delegation_set_id"] = delegation_set_id
        __props__["force_destroy"] = force_destroy
        __props__["name"] = name
        __props__["name_servers"] = name_servers
        __props__["tags"] = tags
        __props__["vpcs"] = vpcs
        __props__["zone_id"] = zone_id
        return Zone(resource_name, opts=opts, __props__=__props__)
    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables

class CertificateValidation(pulumi.CustomResource):
    certificate_arn: pulumi.Output[str]
    """
    The ARN of the certificate that is being validated.
    """
    validation_record_fqdns: pulumi.Output[list]
    """
    List of FQDNs that implement the validation. Only valid for DNS validation method ACM certificates. If this is set, the resource can implement additional sanity checks and has an explicit dependency on the resource that is implementing the validation
    """
    def __init__(__self__, resource_name, opts=None, certificate_arn=None, validation_record_fqdns=None, __props__=None, __name__=None, __opts__=None):
        """
        This resource represents a successful validation of an ACM certificate in concert
        with other resources.

        Most commonly, this resource is used together with `route53.Record` and
        `acm.Certificate` to request a DNS validated certificate,
        deploy the required validation records and wait for validation to complete.

        > **WARNING:** This resource implements a part of the validation workflow. It does not represent a real-world entity in AWS, therefore changing or deleting this resource on its own has no immediate effect.


        ## Example Usage

        ### DNS Validation with Route 53

        ```python
        import pulumi
        import pulumi_aws as aws

        cert_certificate = aws.acm.Certificate("certCertificate",
            domain_name="example.com",
            validation_method="DNS")
        zone = aws.route53.get_zone(name="example.com.",
            private_zone=False)
        cert_validation = aws.route53.Record("certValidation",
            name=cert_certificate.domain_validation_options[0]["resourceRecordName"],
            records=[cert_certificate.domain_validation_options[0]["resourceRecordValue"]],
            ttl=60,
            type=cert_certificate.domain_validation_options[0]["resourceRecordType"],
            zone_id=zone.zone_id)
        cert_certificate_validation = aws.acm.CertificateValidation("certCertificateValidation",
            certificate_arn=cert_certificate.arn,
            validation_record_fqdns=[cert_validation.fqdn])
        front_end = aws.lb.Listener("frontEnd", certificate_arn=cert_certificate_validation.certificate_arn)
        ```

        ### Alternative Domains DNS Validation with Route 53

        ```python
        import pulumi
        import pulumi_aws as aws

        cert_certificate = aws.acm.Certificate("certCertificate",
            domain_name="example.com",
            subject_alternative_names=[
                "www.example.com",
                "example.org",
            ],
            validation_method="DNS")
        zone = aws.route53.get_zone(name="example.com.",
            private_zone=False)
        zone_alt = aws.route53.get_zone(name="example.org.",
            private_zone=False)
        cert_validation = aws.route53.Record("certValidation",
            name=cert_certificate.domain_validation_options[0]["resourceRecordName"],
            records=[cert_certificate.domain_validation_options[0]["resourceRecordValue"]],
            ttl=60,
            type=cert_certificate.domain_validation_options[0]["resourceRecordType"],
            zone_id=zone.zone_id)
        cert_validation_alt1 = aws.route53.Record("certValidationAlt1",
            name=cert_certificate.domain_validation_options[1]["resourceRecordName"],
            records=[cert_certificate.domain_validation_options[1]["resourceRecordValue"]],
            ttl=60,
            type=cert_certificate.domain_validation_options[1]["resourceRecordType"],
            zone_id=zone.zone_id)
        cert_validation_alt2 = aws.route53.Record("certValidationAlt2",
            name=cert_certificate.domain_validation_options[2]["resourceRecordName"],
            records=[cert_certificate.domain_validation_options[2]["resourceRecordValue"]],
            ttl=60,
            type=cert_certificate.domain_validation_options[2]["resourceRecordType"],
            zone_id=zone_alt.zone_id)
        cert_certificate_validation = aws.acm.CertificateValidation("certCertificateValidation",
            certificate_arn=cert_certificate.arn,
            validation_record_fqdns=[
                cert_validation.fqdn,
                cert_validation_alt1.fqdn,
                cert_validation_alt2.fqdn,
            ])
        front_end = aws.lb.Listener("frontEnd", certificate_arn=cert_certificate_validation.certificate_arn)
        ```

        ### Email Validation

        ```python
        import pulumi
        import pulumi_aws as aws

        cert_certificate = aws.acm.Certificate("certCertificate",
            domain_name="example.com",
            validation_method="EMAIL")
        cert_certificate_validation = aws.acm.CertificateValidation("certCertificateValidation", certificate_arn=cert_certificate.arn)
        ```


        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] certificate_arn: The ARN of the certificate that is being validated.
        :param pulumi.Input[list] validation_record_fqdns: List of FQDNs that implement the validation. Only valid for DNS validation method ACM certificates. If this is set, the resource can implement additional sanity checks and has an explicit dependency on the resource that is implementing the validation
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            if certificate_arn is None:
                raise TypeError("Missing required property 'certificate_arn'")
            __props__['certificate_arn'] = certificate_arn
            __props__['validation_record_fqdns'] = validation_record_fqdns
        super(CertificateValidation, __self__).__init__(
            'aws:acm/certificateValidation:CertificateValidation',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, certificate_arn=None, validation_record_fqdns=None):
        """
        Get an existing CertificateValidation resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] certificate_arn: The ARN of the certificate that is being validated.
        :param pulumi.Input[list] validation_record_fqdns: List of FQDNs that implement the validation. Only valid for DNS validation method ACM certificates. If this is set, the resource can implement additional sanity checks and has an explicit dependency on the resource that is implementing the validation
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()

        __props__["certificate_arn"] = certificate_arn
        __props__["validation_record_fqdns"] = validation_record_fqdns
        return CertificateValidation(resource_name, opts=opts, __props__=__props__)
    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop

